import typing

import android.health.connect.changelog
import android.health.connect.datatypes
import android.net
import android.os
import java
import java.lang
import java.time
import java.util
import java.util.concurrent

_AggregateRecordsGroupedByDurationResponse__T = typing.TypeVar('_AggregateRecordsGroupedByDurationResponse__T')  # <T>
class AggregateRecordsGroupedByDurationResponse(java.lang.Object, typing.Generic[_AggregateRecordsGroupedByDurationResponse__T]):
    def get(self, aggregationType: android.health.connect.datatypes.AggregationType[_AggregateRecordsGroupedByDurationResponse__T], /) -> _AggregateRecordsGroupedByDurationResponse__T | None: ...
    def getDataOrigins(self, aggregationType: android.health.connect.datatypes.AggregationType[_AggregateRecordsGroupedByDurationResponse__T], /) -> java.util.Set[android.health.connect.datatypes.DataOrigin]: ...
    def getEndTime(self) -> java.time.Instant: ...
    def getStartTime(self) -> java.time.Instant: ...
    def getZoneOffset(self, aggregationType: android.health.connect.datatypes.AggregationType[_AggregateRecordsGroupedByDurationResponse__T], /) -> java.time.ZoneOffset | None: ...

_AggregateRecordsGroupedByPeriodResponse__T = typing.TypeVar('_AggregateRecordsGroupedByPeriodResponse__T')  # <T>
class AggregateRecordsGroupedByPeriodResponse(java.lang.Object, typing.Generic[_AggregateRecordsGroupedByPeriodResponse__T]):
    def get(self, aggregationType: android.health.connect.datatypes.AggregationType[_AggregateRecordsGroupedByPeriodResponse__T], /) -> _AggregateRecordsGroupedByPeriodResponse__T | None: ...
    def getDataOrigins(self, aggregationType: android.health.connect.datatypes.AggregationType[_AggregateRecordsGroupedByPeriodResponse__T], /) -> java.util.Set[android.health.connect.datatypes.DataOrigin]: ...
    def getEndTime(self) -> java.time.LocalDateTime: ...
    def getStartTime(self) -> java.time.LocalDateTime: ...
    def getZoneOffset(self, aggregationType: android.health.connect.datatypes.AggregationType[_AggregateRecordsGroupedByPeriodResponse__T], /) -> java.time.ZoneOffset | None: ...

_AggregateRecordsRequest__T = typing.TypeVar('_AggregateRecordsRequest__T')  # <T>

_AggregateRecordsRequest__Builder__T = typing.TypeVar('_AggregateRecordsRequest__Builder__T')  # <T>
class AggregateRecordsRequest(java.lang.Object, typing.Generic[_AggregateRecordsRequest__T]):
    def getAggregationTypes(self) -> java.util.Set[android.health.connect.datatypes.AggregationType[_AggregateRecordsRequest__T]]: ...
    def getDataOriginsFilters(self) -> java.util.Set[android.health.connect.datatypes.DataOrigin]: ...
    def getTimeRangeFilter(self) -> TimeRangeFilter: ...
    class Builder(java.lang.Object, typing.Generic[_AggregateRecordsRequest__Builder__T]):
        def __init__(self, timeRangeFilter: TimeRangeFilter, /) -> None: ...
        def addAggregationType(self, aggregationType: android.health.connect.datatypes.AggregationType[_AggregateRecordsRequest__Builder__T], /) -> AggregateRecordsRequest.Builder[_AggregateRecordsRequest__Builder__T]: ...
        def addDataOriginsFilter(self, dataOriginsFilter: android.health.connect.datatypes.DataOrigin, /) -> AggregateRecordsRequest.Builder[_AggregateRecordsRequest__Builder__T]: ...
        def build(self) -> AggregateRecordsRequest[_AggregateRecordsRequest__Builder__T]: ...

_AggregateRecordsResponse__T = typing.TypeVar('_AggregateRecordsResponse__T')  # <T>
class AggregateRecordsResponse(java.lang.Object, typing.Generic[_AggregateRecordsResponse__T]):
    def get(self, aggregationType: android.health.connect.datatypes.AggregationType[_AggregateRecordsResponse__T], /) -> _AggregateRecordsResponse__T | None: ...
    def getDataOrigins(self, aggregationType: android.health.connect.datatypes.AggregationType[_AggregateRecordsResponse__T], /) -> java.util.Set[android.health.connect.datatypes.DataOrigin]: ...
    def getZoneOffset(self, aggregationType: android.health.connect.datatypes.AggregationType[_AggregateRecordsResponse__T], /) -> java.time.ZoneOffset | None: ...

class CreateMedicalDataSourceRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[CreateMedicalDataSourceRequest]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getDisplayName(self) -> str: ...
    def getFhirBaseUri(self) -> android.net.Uri: ...
    def getFhirVersion(self) -> android.health.connect.datatypes.FhirVersion: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self, other: CreateMedicalDataSourceRequest.Builder, /) -> None: ...
        @typing.overload
        def __init__(self, other: CreateMedicalDataSourceRequest, /) -> None: ...
        @typing.overload
        def __init__(self, fhirBaseUri: android.net.Uri, displayName: str | java.lang.String, fhirVersion: android.health.connect.datatypes.FhirVersion, /) -> None: ...
        def build(self) -> CreateMedicalDataSourceRequest: ...
        def setDisplayName(self, displayName: str | java.lang.String, /) -> CreateMedicalDataSourceRequest.Builder: ...
        def setFhirBaseUri(self, fhirBaseUri: android.net.Uri, /) -> CreateMedicalDataSourceRequest.Builder: ...
        def setFhirVersion(self, fhirVersion: android.health.connect.datatypes.FhirVersion, /) -> CreateMedicalDataSourceRequest.Builder: ...

class DeleteMedicalResourcesRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[DeleteMedicalResourcesRequest]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getDataSourceIds(self) -> java.util.Set[java.lang.String]: ...
    def getMedicalResourceTypes(self) -> java.util.Set[java.lang.Integer]: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, other: DeleteMedicalResourcesRequest.Builder, /) -> None: ...
        @typing.overload
        def __init__(self, other: DeleteMedicalResourcesRequest, /) -> None: ...
        def addDataSourceId(self, dataSourceId: str | java.lang.String, /) -> DeleteMedicalResourcesRequest.Builder: ...
        def addMedicalResourceType(self, resourceType: int | java.jint | java.lang.Integer, /) -> DeleteMedicalResourcesRequest.Builder: ...
        def build(self) -> DeleteMedicalResourcesRequest: ...
        def clearDataSourceIds(self) -> DeleteMedicalResourcesRequest.Builder: ...
        def clearMedicalResourceTypes(self) -> DeleteMedicalResourcesRequest.Builder: ...

class GetMedicalDataSourcesRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[GetMedicalDataSourcesRequest]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getPackageNames(self) -> java.util.Set[java.lang.String]: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, other: GetMedicalDataSourcesRequest.Builder, /) -> None: ...
        @typing.overload
        def __init__(self, other: GetMedicalDataSourcesRequest, /) -> None: ...
        def addPackageName(self, packageName: str | java.lang.String, /) -> GetMedicalDataSourcesRequest.Builder: ...
        def build(self) -> GetMedicalDataSourcesRequest: ...
        def clearPackageNames(self) -> GetMedicalDataSourcesRequest.Builder: ...

class HealthConnectException(java.lang.RuntimeException):
    ERROR_DATA_SYNC_IN_PROGRESS: typing.ClassVar[int] = ...
    ERROR_INTERNAL: typing.ClassVar[int] = ...
    ERROR_INVALID_ARGUMENT: typing.ClassVar[int] = ...
    ERROR_IO: typing.ClassVar[int] = ...
    ERROR_RATE_LIMIT_EXCEEDED: typing.ClassVar[int] = ...
    ERROR_REMOTE: typing.ClassVar[int] = ...
    ERROR_SECURITY: typing.ClassVar[int] = ...
    ERROR_UNKNOWN: typing.ClassVar[int] = ...
    ERROR_UNSUPPORTED_OPERATION: typing.ClassVar[int] = ...
    def getErrorCode(self) -> int: ...

class HealthConnectManager(java.lang.Object):
    ACTION_MANAGE_HEALTH_PERMISSIONS: typing.ClassVar[str] = ...
    ACTION_REQUEST_EXERCISE_ROUTE: typing.ClassVar[str] = ...
    CATEGORY_HEALTH_PERMISSIONS: typing.ClassVar[str] = ...
    EXTRA_EXERCISE_ROUTE: typing.ClassVar[str] = ...
    EXTRA_SESSION_ID: typing.ClassVar[str] = ...
    _aggregate__T = typing.TypeVar('_aggregate__T')  # <T>
    def aggregate(self, request: AggregateRecordsRequest[_aggregate__T], executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[AggregateRecordsResponse[_aggregate__T], HealthConnectException], /) -> None: ...
    _aggregateGroupByDuration__T = typing.TypeVar('_aggregateGroupByDuration__T')  # <T>
    def aggregateGroupByDuration(self, request: AggregateRecordsRequest[_aggregateGroupByDuration__T], duration: java.time.Duration, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[java.util.List[AggregateRecordsGroupedByDurationResponse[_aggregateGroupByDuration__T]], HealthConnectException], /) -> None: ...
    _aggregateGroupByPeriod__T = typing.TypeVar('_aggregateGroupByPeriod__T')  # <T>
    def aggregateGroupByPeriod(self, request: AggregateRecordsRequest[_aggregateGroupByPeriod__T], period: java.time.Period, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[java.util.List[AggregateRecordsGroupedByPeriodResponse[_aggregateGroupByPeriod__T]], HealthConnectException], /) -> None: ...
    def createMedicalDataSource(self, request: CreateMedicalDataSourceRequest, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[android.health.connect.datatypes.MedicalDataSource, HealthConnectException], /) -> None: ...
    def deleteMedicalDataSourceWithData(self, id: str | java.lang.String, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[java.lang.Void, HealthConnectException], /) -> None: ...
    @typing.overload
    def deleteMedicalResources(self, request: DeleteMedicalResourcesRequest, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[java.lang.Void, HealthConnectException], /) -> None: ...
    @typing.overload
    def deleteMedicalResources(self, ids: java.util.List[MedicalResourceId], executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[java.lang.Void, HealthConnectException], /) -> None: ...
    @typing.overload
    def deleteRecords(self, recordIds: java.util.List[RecordIdFilter], executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[java.lang.Void, HealthConnectException], /) -> None: ...
    @typing.overload
    def deleteRecords(self, recordType: typing.Type[android.health.connect.datatypes.Record], timeRangeFilter: TimeRangeFilter, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[java.lang.Void, HealthConnectException], /) -> None: ...
    def getChangeLogToken(self, request: android.health.connect.changelog.ChangeLogTokenRequest, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[android.health.connect.changelog.ChangeLogTokenResponse, HealthConnectException], /) -> None: ...
    def getChangeLogs(self, changeLogsRequest: android.health.connect.changelog.ChangeLogsRequest, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[android.health.connect.changelog.ChangeLogsResponse, HealthConnectException], /) -> None: ...
    @typing.overload
    def getMedicalDataSources(self, request: GetMedicalDataSourcesRequest, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[java.util.List[android.health.connect.datatypes.MedicalDataSource], HealthConnectException], /) -> None: ...
    @typing.overload
    def getMedicalDataSources(self, ids: java.util.List[java.lang.String], executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[java.util.List[android.health.connect.datatypes.MedicalDataSource], HealthConnectException], /) -> None: ...
    def insertRecords(self, records: java.util.List[android.health.connect.datatypes.Record], executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[InsertRecordsResponse, HealthConnectException], /) -> None: ...
    @typing.overload
    def readMedicalResources(self, request: ReadMedicalResourcesRequest, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[ReadMedicalResourcesResponse, HealthConnectException], /) -> None: ...
    @typing.overload
    def readMedicalResources(self, ids: java.util.List[MedicalResourceId], executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[java.util.List[android.health.connect.datatypes.MedicalResource], HealthConnectException], /) -> None: ...
    _readRecords__T = typing.TypeVar('_readRecords__T', bound=android.health.connect.datatypes.Record)  # <T>
    def readRecords(self, request: ReadRecordsRequest[_readRecords__T], executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[ReadRecordsResponse[_readRecords__T], HealthConnectException], /) -> None: ...
    def updateRecords(self, records: java.util.List[android.health.connect.datatypes.Record], executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[java.lang.Void, HealthConnectException], /) -> None: ...
    def upsertMedicalResources(self, requests: java.util.List[UpsertMedicalResourceRequest], executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[java.util.List[android.health.connect.datatypes.MedicalResource], HealthConnectException], /) -> None: ...

class HealthPermissions(java.lang.Object):
    READ_ACTIVE_CALORIES_BURNED: typing.ClassVar[str] = ...
    READ_ACTIVITY_INTENSITY: typing.ClassVar[str] = ...
    READ_BASAL_BODY_TEMPERATURE: typing.ClassVar[str] = ...
    READ_BASAL_METABOLIC_RATE: typing.ClassVar[str] = ...
    READ_BLOOD_GLUCOSE: typing.ClassVar[str] = ...
    READ_BLOOD_PRESSURE: typing.ClassVar[str] = ...
    READ_BODY_FAT: typing.ClassVar[str] = ...
    READ_BODY_TEMPERATURE: typing.ClassVar[str] = ...
    READ_BODY_WATER_MASS: typing.ClassVar[str] = ...
    READ_BONE_MASS: typing.ClassVar[str] = ...
    READ_CERVICAL_MUCUS: typing.ClassVar[str] = ...
    READ_DISTANCE: typing.ClassVar[str] = ...
    READ_ELEVATION_GAINED: typing.ClassVar[str] = ...
    READ_EXERCISE: typing.ClassVar[str] = ...
    READ_EXERCISE_ROUTES: typing.ClassVar[str] = ...
    READ_FLOORS_CLIMBED: typing.ClassVar[str] = ...
    READ_HEALTH_DATA_HISTORY: typing.ClassVar[str] = ...
    READ_HEALTH_DATA_IN_BACKGROUND: typing.ClassVar[str] = ...
    READ_HEART_RATE: typing.ClassVar[str] = ...
    READ_HEART_RATE_VARIABILITY: typing.ClassVar[str] = ...
    READ_HEIGHT: typing.ClassVar[str] = ...
    READ_HYDRATION: typing.ClassVar[str] = ...
    READ_INTERMENSTRUAL_BLEEDING: typing.ClassVar[str] = ...
    READ_LEAN_BODY_MASS: typing.ClassVar[str] = ...
    READ_MEDICAL_DATA_ALLERGIES_INTOLERANCES: typing.ClassVar[str] = ...
    READ_MEDICAL_DATA_CONDITIONS: typing.ClassVar[str] = ...
    READ_MEDICAL_DATA_LABORATORY_RESULTS: typing.ClassVar[str] = ...
    READ_MEDICAL_DATA_MEDICATIONS: typing.ClassVar[str] = ...
    READ_MEDICAL_DATA_PERSONAL_DETAILS: typing.ClassVar[str] = ...
    READ_MEDICAL_DATA_PRACTITIONER_DETAILS: typing.ClassVar[str] = ...
    READ_MEDICAL_DATA_PREGNANCY: typing.ClassVar[str] = ...
    READ_MEDICAL_DATA_PROCEDURES: typing.ClassVar[str] = ...
    READ_MEDICAL_DATA_SOCIAL_HISTORY: typing.ClassVar[str] = ...
    READ_MEDICAL_DATA_VACCINES: typing.ClassVar[str] = ...
    READ_MEDICAL_DATA_VISITS: typing.ClassVar[str] = ...
    READ_MEDICAL_DATA_VITAL_SIGNS: typing.ClassVar[str] = ...
    READ_MENSTRUATION: typing.ClassVar[str] = ...
    READ_MINDFULNESS: typing.ClassVar[str] = ...
    READ_NUTRITION: typing.ClassVar[str] = ...
    READ_OVULATION_TEST: typing.ClassVar[str] = ...
    READ_OXYGEN_SATURATION: typing.ClassVar[str] = ...
    READ_PLANNED_EXERCISE: typing.ClassVar[str] = ...
    READ_POWER: typing.ClassVar[str] = ...
    READ_RESPIRATORY_RATE: typing.ClassVar[str] = ...
    READ_RESTING_HEART_RATE: typing.ClassVar[str] = ...
    READ_SEXUAL_ACTIVITY: typing.ClassVar[str] = ...
    READ_SKIN_TEMPERATURE: typing.ClassVar[str] = ...
    READ_SLEEP: typing.ClassVar[str] = ...
    READ_SPEED: typing.ClassVar[str] = ...
    READ_STEPS: typing.ClassVar[str] = ...
    READ_TOTAL_CALORIES_BURNED: typing.ClassVar[str] = ...
    READ_VO2_MAX: typing.ClassVar[str] = ...
    READ_WEIGHT: typing.ClassVar[str] = ...
    READ_WHEELCHAIR_PUSHES: typing.ClassVar[str] = ...
    WRITE_ACTIVE_CALORIES_BURNED: typing.ClassVar[str] = ...
    WRITE_ACTIVITY_INTENSITY: typing.ClassVar[str] = ...
    WRITE_BASAL_BODY_TEMPERATURE: typing.ClassVar[str] = ...
    WRITE_BASAL_METABOLIC_RATE: typing.ClassVar[str] = ...
    WRITE_BLOOD_GLUCOSE: typing.ClassVar[str] = ...
    WRITE_BLOOD_PRESSURE: typing.ClassVar[str] = ...
    WRITE_BODY_FAT: typing.ClassVar[str] = ...
    WRITE_BODY_TEMPERATURE: typing.ClassVar[str] = ...
    WRITE_BODY_WATER_MASS: typing.ClassVar[str] = ...
    WRITE_BONE_MASS: typing.ClassVar[str] = ...
    WRITE_CERVICAL_MUCUS: typing.ClassVar[str] = ...
    WRITE_DISTANCE: typing.ClassVar[str] = ...
    WRITE_ELEVATION_GAINED: typing.ClassVar[str] = ...
    WRITE_EXERCISE: typing.ClassVar[str] = ...
    WRITE_EXERCISE_ROUTE: typing.ClassVar[str] = ...
    WRITE_FLOORS_CLIMBED: typing.ClassVar[str] = ...
    WRITE_HEART_RATE: typing.ClassVar[str] = ...
    WRITE_HEART_RATE_VARIABILITY: typing.ClassVar[str] = ...
    WRITE_HEIGHT: typing.ClassVar[str] = ...
    WRITE_HYDRATION: typing.ClassVar[str] = ...
    WRITE_INTERMENSTRUAL_BLEEDING: typing.ClassVar[str] = ...
    WRITE_LEAN_BODY_MASS: typing.ClassVar[str] = ...
    WRITE_MEDICAL_DATA: typing.ClassVar[str] = ...
    WRITE_MENSTRUATION: typing.ClassVar[str] = ...
    WRITE_MINDFULNESS: typing.ClassVar[str] = ...
    WRITE_NUTRITION: typing.ClassVar[str] = ...
    WRITE_OVULATION_TEST: typing.ClassVar[str] = ...
    WRITE_OXYGEN_SATURATION: typing.ClassVar[str] = ...
    WRITE_PLANNED_EXERCISE: typing.ClassVar[str] = ...
    WRITE_POWER: typing.ClassVar[str] = ...
    WRITE_RESPIRATORY_RATE: typing.ClassVar[str] = ...
    WRITE_RESTING_HEART_RATE: typing.ClassVar[str] = ...
    WRITE_SEXUAL_ACTIVITY: typing.ClassVar[str] = ...
    WRITE_SKIN_TEMPERATURE: typing.ClassVar[str] = ...
    WRITE_SLEEP: typing.ClassVar[str] = ...
    WRITE_SPEED: typing.ClassVar[str] = ...
    WRITE_STEPS: typing.ClassVar[str] = ...
    WRITE_TOTAL_CALORIES_BURNED: typing.ClassVar[str] = ...
    WRITE_VO2_MAX: typing.ClassVar[str] = ...
    WRITE_WEIGHT: typing.ClassVar[str] = ...
    WRITE_WHEELCHAIR_PUSHES: typing.ClassVar[str] = ...

class InsertRecordsResponse(java.lang.Object):
    def getRecords(self) -> java.util.List[android.health.connect.datatypes.Record]: ...

class LocalTimeRangeFilter(TimeRangeFilter):
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getEndTime(self) -> java.time.LocalDateTime | None: ...
    def getStartTime(self) -> java.time.LocalDateTime | None: ...
    def hashCode(self) -> int: ...
    def isBounded(self) -> bool: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> LocalTimeRangeFilter: ...
        def setEndTime(self, localEndTime: java.time.LocalDateTime, /) -> LocalTimeRangeFilter.Builder: ...
        def setStartTime(self, localStartTime: java.time.LocalDateTime, /) -> LocalTimeRangeFilter.Builder: ...

class MedicalResourceId(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[MedicalResourceId]] = ...
    def __init__(self, dataSourceId: str | java.lang.String, fhirResourceType: int | java.jint | java.lang.Integer, fhirResourceId: str | java.lang.String, /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def fromFhirReference(dataSourceId: str | java.lang.String, fhirReference: str | java.lang.String, /) -> MedicalResourceId: ...
    def getDataSourceId(self) -> str: ...
    def getFhirResourceId(self) -> str: ...
    def getFhirResourceType(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class ReadMedicalResourcesInitialRequest(ReadMedicalResourcesRequest):
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getDataSourceIds(self) -> java.util.Set[java.lang.String]: ...
    def getMedicalResourceType(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self, medicalResourceType: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def __init__(self, other: ReadMedicalResourcesInitialRequest.Builder, /) -> None: ...
        @typing.overload
        def __init__(self, other: ReadMedicalResourcesInitialRequest, /) -> None: ...
        def addDataSourceId(self, dataSourceId: str | java.lang.String, /) -> ReadMedicalResourcesInitialRequest.Builder: ...
        def addDataSourceIds(self, dataSourceIds: java.util.Set[java.lang.String], /) -> ReadMedicalResourcesInitialRequest.Builder: ...
        def build(self) -> ReadMedicalResourcesInitialRequest: ...
        def clearDataSourceIds(self) -> ReadMedicalResourcesInitialRequest.Builder: ...
        def setMedicalResourceType(self, medicalResourceType: int | java.jint | java.lang.Integer, /) -> ReadMedicalResourcesInitialRequest.Builder: ...
        def setPageSize(self, pageSize: int | java.jint | java.lang.Integer, /) -> ReadMedicalResourcesInitialRequest.Builder: ...

class ReadMedicalResourcesPageRequest(ReadMedicalResourcesRequest):
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getPageToken(self) -> str: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self, other: ReadMedicalResourcesPageRequest.Builder, /) -> None: ...
        @typing.overload
        def __init__(self, other: ReadMedicalResourcesPageRequest, /) -> None: ...
        @typing.overload
        def __init__(self, pageToken: str | java.lang.String, /) -> None: ...
        def build(self) -> ReadMedicalResourcesPageRequest: ...
        def setPageSize(self, pageSize: int | java.jint | java.lang.Integer, /) -> ReadMedicalResourcesPageRequest.Builder: ...
        def setPageToken(self, pageToken: str | java.lang.String, /) -> ReadMedicalResourcesPageRequest.Builder: ...

class ReadMedicalResourcesRequest(java.lang.Object):
    def getPageSize(self) -> int: ...

class ReadMedicalResourcesResponse(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ReadMedicalResourcesResponse]] = ...
    def __init__(self, medicalResources: java.util.List[android.health.connect.datatypes.MedicalResource], nextPageToken: str | java.lang.String, remainingCount: int | java.jint | java.lang.Integer, /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getMedicalResources(self) -> java.util.List[android.health.connect.datatypes.MedicalResource]: ...
    def getNextPageToken(self) -> str: ...
    def getRemainingCount(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

_ReadRecordsRequest__T = typing.TypeVar('_ReadRecordsRequest__T', bound=android.health.connect.datatypes.Record)  # <T>
class ReadRecordsRequest(java.lang.Object, typing.Generic[_ReadRecordsRequest__T]):
    def getRecordType(self) -> typing.Type[_ReadRecordsRequest__T]: ...

_ReadRecordsRequestUsingFilters__T = typing.TypeVar('_ReadRecordsRequestUsingFilters__T', bound=android.health.connect.datatypes.Record)  # <T>

_ReadRecordsRequestUsingFilters__Builder__T = typing.TypeVar('_ReadRecordsRequestUsingFilters__Builder__T', bound=android.health.connect.datatypes.Record)  # <T>
class ReadRecordsRequestUsingFilters(ReadRecordsRequest[_ReadRecordsRequestUsingFilters__T], typing.Generic[_ReadRecordsRequestUsingFilters__T]):
    def getDataOrigins(self) -> java.util.Set[android.health.connect.datatypes.DataOrigin]: ...
    def getPageSize(self) -> int: ...
    def getPageToken(self) -> int: ...
    def getTimeRangeFilter(self) -> TimeRangeFilter | None: ...
    def isAscending(self) -> bool: ...
    class Builder(java.lang.Object, typing.Generic[_ReadRecordsRequestUsingFilters__Builder__T]):
        def __init__(self, recordType: typing.Type[_ReadRecordsRequestUsingFilters__Builder__T], /) -> None: ...
        def addDataOrigins(self, dataOrigin: android.health.connect.datatypes.DataOrigin, /) -> ReadRecordsRequestUsingFilters.Builder[_ReadRecordsRequestUsingFilters__Builder__T]: ...
        def build(self) -> ReadRecordsRequestUsingFilters[_ReadRecordsRequestUsingFilters__Builder__T]: ...
        def setAscending(self, ascending: bool | java.jboolean | java.lang.Boolean, /) -> ReadRecordsRequestUsingFilters.Builder[_ReadRecordsRequestUsingFilters__Builder__T]: ...
        def setPageSize(self, pageSize: int | java.jint | java.lang.Integer, /) -> ReadRecordsRequestUsingFilters.Builder[_ReadRecordsRequestUsingFilters__Builder__T]: ...
        def setPageToken(self, pageToken: int | java.jlong | java.lang.Long, /) -> ReadRecordsRequestUsingFilters.Builder[_ReadRecordsRequestUsingFilters__Builder__T]: ...
        def setTimeRangeFilter(self, timeRangeFilter: TimeRangeFilter, /) -> ReadRecordsRequestUsingFilters.Builder[_ReadRecordsRequestUsingFilters__Builder__T]: ...

_ReadRecordsRequestUsingIds__T = typing.TypeVar('_ReadRecordsRequestUsingIds__T', bound=android.health.connect.datatypes.Record)  # <T>

_ReadRecordsRequestUsingIds__Builder__T = typing.TypeVar('_ReadRecordsRequestUsingIds__Builder__T', bound=android.health.connect.datatypes.Record)  # <T>
class ReadRecordsRequestUsingIds(ReadRecordsRequest[_ReadRecordsRequestUsingIds__T], typing.Generic[_ReadRecordsRequestUsingIds__T]):
    def getRecordIdFilters(self) -> java.util.List[RecordIdFilter]: ...
    class Builder(java.lang.Object, typing.Generic[_ReadRecordsRequestUsingIds__Builder__T]):
        def __init__(self, recordType: typing.Type[_ReadRecordsRequestUsingIds__Builder__T], /) -> None: ...
        def addClientRecordId(self, clientRecordId: str | java.lang.String, /) -> ReadRecordsRequestUsingIds.Builder[_ReadRecordsRequestUsingIds__Builder__T]: ...
        def addId(self, id: str | java.lang.String, /) -> ReadRecordsRequestUsingIds.Builder[_ReadRecordsRequestUsingIds__Builder__T]: ...
        def build(self) -> ReadRecordsRequestUsingIds[_ReadRecordsRequestUsingIds__Builder__T]: ...

_ReadRecordsResponse__T = typing.TypeVar('_ReadRecordsResponse__T', bound=android.health.connect.datatypes.Record)  # <T>
class ReadRecordsResponse(java.lang.Object, typing.Generic[_ReadRecordsResponse__T]):
    def getNextPageToken(self) -> int: ...
    def getRecords(self) -> java.util.List[_ReadRecordsResponse__T]: ...

class RecordIdFilter(java.lang.Object):
    @staticmethod
    def fromClientRecordId(recordType: typing.Type[android.health.connect.datatypes.Record], clientRecordId: str | java.lang.String, /) -> RecordIdFilter: ...
    @staticmethod
    def fromId(recordType: typing.Type[android.health.connect.datatypes.Record], id: str | java.lang.String, /) -> RecordIdFilter: ...
    def getClientRecordId(self) -> str | None: ...
    def getId(self) -> str | None: ...
    def getRecordType(self) -> typing.Type[android.health.connect.datatypes.Record]: ...

class TimeInstantRangeFilter(TimeRangeFilter):
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getEndTime(self) -> java.time.Instant | None: ...
    def getStartTime(self) -> java.time.Instant | None: ...
    def hashCode(self) -> int: ...
    def isBounded(self) -> bool: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> TimeInstantRangeFilter: ...
        def setEndTime(self, endTime: java.time.Instant, /) -> TimeInstantRangeFilter.Builder: ...
        def setStartTime(self, startTime: java.time.Instant, /) -> TimeInstantRangeFilter.Builder: ...

class TimeRangeFilter(java.lang.Object): ...

class UpsertMedicalResourceRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[UpsertMedicalResourceRequest]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getData(self) -> str: ...
    def getDataSourceId(self) -> str: ...
    def getFhirVersion(self) -> android.health.connect.datatypes.FhirVersion: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self, other: UpsertMedicalResourceRequest.Builder, /) -> None: ...
        @typing.overload
        def __init__(self, other: UpsertMedicalResourceRequest, /) -> None: ...
        @typing.overload
        def __init__(self, dataSourceId: str | java.lang.String, fhirVersion: android.health.connect.datatypes.FhirVersion, data: str | java.lang.String, /) -> None: ...
        def build(self) -> UpsertMedicalResourceRequest: ...
        def setData(self, data: str | java.lang.String, /) -> UpsertMedicalResourceRequest.Builder: ...
        def setDataSourceId(self, dataSourceId: str | java.lang.String, /) -> UpsertMedicalResourceRequest.Builder: ...
        def setFhirVersion(self, fhirVersion: android.health.connect.datatypes.FhirVersion, /) -> UpsertMedicalResourceRequest.Builder: ...



import typing

import android.content
import android.os
import android.service.credentials
import java
import java.lang
import java.util
import java.util.concurrent

class ClearCredentialStateException(java.lang.Exception):
    TYPE_UNKNOWN: typing.ClassVar[str] = ...
    @typing.overload
    def __init__(self, type: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, type: str | java.lang.String, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, type: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...
    @typing.overload
    def __init__(self, type: str | java.lang.String, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...
    def getType(self) -> str: ...

class ClearCredentialStateRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ClearCredentialStateRequest]] = ...
    def __init__(self, data: android.os.Bundle, /) -> None: ...
    def describeContents(self) -> int: ...
    def getData(self) -> android.os.Bundle: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class CreateCredentialException(java.lang.Exception):
    TYPE_INTERRUPTED: typing.ClassVar[str] = ...
    TYPE_NO_CREATE_OPTIONS: typing.ClassVar[str] = ...
    TYPE_UNKNOWN: typing.ClassVar[str] = ...
    TYPE_USER_CANCELED: typing.ClassVar[str] = ...
    @typing.overload
    def __init__(self, type: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, type: str | java.lang.String, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, type: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...
    @typing.overload
    def __init__(self, type: str | java.lang.String, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...
    def getType(self) -> str: ...

class CreateCredentialRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[CreateCredentialRequest]] = ...
    def alwaysSendAppInfoToProvider(self) -> bool: ...
    def describeContents(self) -> int: ...
    def getCandidateQueryData(self) -> android.os.Bundle: ...
    def getCredentialData(self) -> android.os.Bundle: ...
    def getOrigin(self) -> str | None: ...
    def getType(self) -> str: ...
    def isSystemProviderRequired(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, type: str | java.lang.String, credentialData: android.os.Bundle, candidateQueryData: android.os.Bundle, /) -> None: ...
        def build(self) -> CreateCredentialRequest: ...
        def setAlwaysSendAppInfoToProvider(self, value: bool | java.jboolean | java.lang.Boolean, /) -> CreateCredentialRequest.Builder: ...
        def setIsSystemProviderRequired(self, value: bool | java.jboolean | java.lang.Boolean, /) -> CreateCredentialRequest.Builder: ...
        def setOrigin(self, origin: str | java.lang.String, /) -> CreateCredentialRequest.Builder: ...

class CreateCredentialResponse(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[CreateCredentialResponse]] = ...
    def __init__(self, data: android.os.Bundle, /) -> None: ...
    def describeContents(self) -> int: ...
    def getData(self) -> android.os.Bundle: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class Credential(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[Credential]] = ...
    TYPE_PASSWORD_CREDENTIAL: typing.ClassVar[str] = ...
    def __init__(self, type: str | java.lang.String, data: android.os.Bundle, /) -> None: ...
    def describeContents(self) -> int: ...
    def getData(self) -> android.os.Bundle: ...
    def getType(self) -> str: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class CredentialDescription(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[CredentialDescription]] = ...
    def __init__(self, type: str | java.lang.String, supportedElementKeys: java.util.Set[java.lang.String], credentialEntries: java.util.List[android.service.credentials.CredentialEntry], /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getCredentialEntries(self) -> java.util.List[android.service.credentials.CredentialEntry]: ...
    def getSupportedElementKeys(self) -> java.util.Set[java.lang.String]: ...
    def getType(self) -> str: ...
    def hashCode(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class CredentialManager(java.lang.Object):
    def clearCredentialState(self, request: ClearCredentialStateRequest, cancellationSignal: android.os.CancellationSignal, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[java.lang.Void, ClearCredentialStateException], /) -> None: ...
    def createCredential(self, context: android.content.Context, request: CreateCredentialRequest, cancellationSignal: android.os.CancellationSignal, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[CreateCredentialResponse, CreateCredentialException], /) -> None: ...
    @typing.overload
    def getCredential(self, context: android.content.Context, request: GetCredentialRequest, cancellationSignal: android.os.CancellationSignal, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[GetCredentialResponse, GetCredentialException], /) -> None: ...
    @typing.overload
    def getCredential(self, context: android.content.Context, pendingGetCredentialHandle: PrepareGetCredentialResponse.PendingGetCredentialHandle, cancellationSignal: android.os.CancellationSignal, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[GetCredentialResponse, GetCredentialException], /) -> None: ...
    def isEnabledCredentialProviderService(self, componentName: android.content.ComponentName, /) -> bool: ...
    def prepareGetCredential(self, request: GetCredentialRequest, cancellationSignal: android.os.CancellationSignal, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[PrepareGetCredentialResponse, GetCredentialException], /) -> None: ...
    def registerCredentialDescription(self, request: RegisterCredentialDescriptionRequest, /) -> None: ...
    def unregisterCredentialDescription(self, request: UnregisterCredentialDescriptionRequest, /) -> None: ...

class CredentialOption(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[CredentialOption]] = ...
    SUPPORTED_ELEMENT_KEYS: typing.ClassVar[str] = ...
    def describeContents(self) -> int: ...
    def getAllowedProviders(self) -> java.util.Set[android.content.ComponentName]: ...
    def getCandidateQueryData(self) -> android.os.Bundle: ...
    def getCredentialRetrievalData(self) -> android.os.Bundle: ...
    def getType(self) -> str: ...
    def isSystemProviderRequired(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, type: str | java.lang.String, credentialRetrievalData: android.os.Bundle, candidateQueryData: android.os.Bundle, /) -> None: ...
        def addAllowedProvider(self, allowedProvider: android.content.ComponentName, /) -> CredentialOption.Builder: ...
        def build(self) -> CredentialOption: ...
        def setAllowedProviders(self, allowedProviders: java.util.Set[android.content.ComponentName], /) -> CredentialOption.Builder: ...
        def setIsSystemProviderRequired(self, isSystemProviderRequired: bool | java.jboolean | java.lang.Boolean, /) -> CredentialOption.Builder: ...

class GetCredentialException(java.lang.Exception):
    TYPE_INTERRUPTED: typing.ClassVar[str] = ...
    TYPE_NO_CREDENTIAL: typing.ClassVar[str] = ...
    TYPE_UNKNOWN: typing.ClassVar[str] = ...
    TYPE_USER_CANCELED: typing.ClassVar[str] = ...
    @typing.overload
    def __init__(self, type: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, type: str | java.lang.String, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, type: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...
    @typing.overload
    def __init__(self, type: str | java.lang.String, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...
    def getType(self) -> str: ...

class GetCredentialRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[GetCredentialRequest]] = ...
    def alwaysSendAppInfoToProvider(self) -> bool: ...
    def describeContents(self) -> int: ...
    def getCredentialOptions(self) -> java.util.List[CredentialOption]: ...
    def getData(self) -> android.os.Bundle: ...
    def getOrigin(self) -> str | None: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, data: android.os.Bundle, /) -> None: ...
        def addCredentialOption(self, credentialOption: CredentialOption, /) -> GetCredentialRequest.Builder: ...
        def build(self) -> GetCredentialRequest: ...
        def setAlwaysSendAppInfoToProvider(self, value: bool | java.jboolean | java.lang.Boolean, /) -> GetCredentialRequest.Builder: ...
        def setCredentialOptions(self, credentialOptions: java.util.List[CredentialOption], /) -> GetCredentialRequest.Builder: ...
        def setOrigin(self, origin: str | java.lang.String, /) -> GetCredentialRequest.Builder: ...

class GetCredentialResponse(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[GetCredentialResponse]] = ...
    def __init__(self, credential: Credential, /) -> None: ...
    def describeContents(self) -> int: ...
    def getCredential(self) -> Credential: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class PrepareGetCredentialResponse(java.lang.Object):
    def getPendingGetCredentialHandle(self) -> PrepareGetCredentialResponse.PendingGetCredentialHandle: ...
    def hasAuthenticationResults(self) -> bool: ...
    def hasCredentialResults(self, credentialType: str | java.lang.String, /) -> bool: ...
    def hasRemoteResults(self) -> bool: ...

    class PendingGetCredentialHandle(java.lang.Object): ...

class RegisterCredentialDescriptionRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[RegisterCredentialDescriptionRequest]] = ...
    @typing.overload
    def __init__(self, credentialDescription: CredentialDescription, /) -> None: ...
    @typing.overload
    def __init__(self, credentialDescriptions: java.util.Set[CredentialDescription], /) -> None: ...
    def describeContents(self) -> int: ...
    def getCredentialDescriptions(self) -> java.util.Set[CredentialDescription]: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class UnregisterCredentialDescriptionRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[UnregisterCredentialDescriptionRequest]] = ...
    @typing.overload
    def __init__(self, credentialDescription: CredentialDescription, /) -> None: ...
    @typing.overload
    def __init__(self, credentialDescriptions: java.util.Set[CredentialDescription], /) -> None: ...
    def describeContents(self) -> int: ...
    def getCredentialDescriptions(self) -> java.util.Set[CredentialDescription]: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...



import typing

import android.os
import android.telephony
import java
import java.lang

class CdmaCellLocation(android.telephony.CellLocation):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, bundle: android.os.Bundle, /) -> None: ...
    @staticmethod
    def convertQuartSecToDecDegrees(quartSec: int | java.jint | java.lang.Integer, /) -> float: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def fillInNotifierBundle(self, bundleToFill: android.os.Bundle, /) -> None: ...
    def getBaseStationId(self) -> int: ...
    def getBaseStationLatitude(self) -> int: ...
    def getBaseStationLongitude(self) -> int: ...
    def getNetworkId(self) -> int: ...
    def getSystemId(self) -> int: ...
    def hashCode(self) -> int: ...
    @typing.overload
    def setCellLocationData(self, baseStationId: int | java.jint | java.lang.Integer, baseStationLatitude: int | java.jint | java.lang.Integer, baseStationLongitude: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setCellLocationData(self, baseStationId: int | java.jint | java.lang.Integer, baseStationLatitude: int | java.jint | java.lang.Integer, baseStationLongitude: int | java.jint | java.lang.Integer, systemId: int | java.jint | java.lang.Integer, networkId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setStateInvalid(self) -> None: ...
    def toString(self) -> str: ...



import typing

import java.chaquopy
import java.lang
import java.lang.reflect

class Annotation(java.lang.Object):
    def annotationType(self) -> typing.Type[Annotation]: ...
    def equals(self, arg1: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class AnnotationFormatError(java.lang.Error):
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, cause: java.lang.Throwable, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...

class AnnotationTypeMismatchException(java.lang.RuntimeException):
    def __init__(self, element: java.lang.reflect.Method, foundType: str | java.lang.String, /) -> None: ...
    def element(self) -> java.lang.reflect.Method: ...
    def foundType(self) -> str: ...

class Documented(Annotation): ...

class ElementType(java.lang.Enum[ElementType]):
    ANNOTATION_TYPE: typing.ClassVar[ElementType] = ...
    CONSTRUCTOR: typing.ClassVar[ElementType] = ...
    FIELD: typing.ClassVar[ElementType] = ...
    LOCAL_VARIABLE: typing.ClassVar[ElementType] = ...
    METHOD: typing.ClassVar[ElementType] = ...
    MODULE: typing.ClassVar[ElementType] = ...
    PACKAGE: typing.ClassVar[ElementType] = ...
    PARAMETER: typing.ClassVar[ElementType] = ...
    RECORD_COMPONENT: typing.ClassVar[ElementType] = ...
    TYPE: typing.ClassVar[ElementType] = ...
    TYPE_PARAMETER: typing.ClassVar[ElementType] = ...
    TYPE_USE: typing.ClassVar[ElementType] = ...
    @staticmethod
    def valueOf(name: str | java.lang.String, /) -> ElementType: ...
    @staticmethod
    def values() -> java.chaquopy.JavaArray[ElementType]: ...

class IncompleteAnnotationException(java.lang.RuntimeException):
    def __init__(self, annotationType: typing.Type[Annotation], elementName: str | java.lang.String, /) -> None: ...
    def annotationType(self) -> typing.Type[Annotation]: ...
    def elementName(self) -> str: ...

class Inherited(Annotation): ...

class Native(Annotation): ...

class Repeatable(Annotation):
    def value(self) -> typing.Type[Annotation]: ...

class Retention(Annotation):
    def value(self) -> RetentionPolicy: ...

class RetentionPolicy(java.lang.Enum[RetentionPolicy]):
    CLASS: typing.ClassVar[RetentionPolicy] = ...
    RUNTIME: typing.ClassVar[RetentionPolicy] = ...
    SOURCE: typing.ClassVar[RetentionPolicy] = ...
    @staticmethod
    def valueOf(name: str | java.lang.String, /) -> RetentionPolicy: ...
    @staticmethod
    def values() -> java.chaquopy.JavaArray[RetentionPolicy]: ...

class Target(Annotation):
    def value(self) -> java.chaquopy.JavaArray[ElementType]: ...



import java
import java.lang
import java.util.concurrent

class SatelliteManager(java.lang.Object):
    def registerStateChangeListener(self, executor: java.util.concurrent.Executor, listener: SatelliteStateChangeListener, /) -> None: ...
    def unregisterStateChangeListener(self, listener: SatelliteStateChangeListener, /) -> None: ...

class SatelliteStateChangeListener(java.lang.Object):
    def onEnabledStateChanged(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...



import typing

import android.os
import java
import java.lang

class BleRssiRangingParams(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[BleRssiRangingParams]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getPeerBluetoothAddress(self) -> str: ...
    def getRangingUpdateRate(self) -> int: ...
    def hashCode(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, peerBluetoothAddress: str | java.lang.String, /) -> None: ...
        def build(self) -> BleRssiRangingParams: ...
        def setRangingUpdateRate(self, updateRate: int | java.jint | java.lang.Integer, /) -> BleRssiRangingParams.Builder: ...



import typing

import android.content
import android.net
import java
import java.chaquopy
import java.io
import java.lang
import java.util

class DrmConvertedStatus(java.lang.Object):
    STATUS_ERROR: typing.ClassVar[int] = ...
    STATUS_INPUTDATA_ERROR: typing.ClassVar[int] = ...
    STATUS_OK: typing.ClassVar[int] = ...
    convertedData: java.chaquopy.JavaArrayJByte = ...
    offset: int = ...
    statusCode: int = ...
    def __init__(self, statusCode: int | java.jint | java.lang.Integer, convertedData: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, /) -> None: ...

class DrmErrorEvent(DrmEvent):
    TYPE_ACQUIRE_DRM_INFO_FAILED: typing.ClassVar[int] = ...
    TYPE_NOT_SUPPORTED: typing.ClassVar[int] = ...
    TYPE_NO_INTERNET_CONNECTION: typing.ClassVar[int] = ...
    TYPE_OUT_OF_MEMORY: typing.ClassVar[int] = ...
    TYPE_PROCESS_DRM_INFO_FAILED: typing.ClassVar[int] = ...
    TYPE_REMOVE_ALL_RIGHTS_FAILED: typing.ClassVar[int] = ...
    TYPE_RIGHTS_NOT_INSTALLED: typing.ClassVar[int] = ...
    TYPE_RIGHTS_RENEWAL_NOT_ALLOWED: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, uniqueId: int | java.jint | java.lang.Integer, type: int | java.jint | java.lang.Integer, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, uniqueId: int | java.jint | java.lang.Integer, type: int | java.jint | java.lang.Integer, message: str | java.lang.String, attributes: java.util.HashMap[java.lang.String, java.lang.Object], /) -> None: ...

class DrmEvent(java.lang.Object):
    DRM_INFO_OBJECT: typing.ClassVar[str] = ...
    DRM_INFO_STATUS_OBJECT: typing.ClassVar[str] = ...
    TYPE_ALL_RIGHTS_REMOVED: typing.ClassVar[int] = ...
    TYPE_DRM_INFO_PROCESSED: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, uniqueId: int | java.jint | java.lang.Integer, type: int | java.jint | java.lang.Integer, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, uniqueId: int | java.jint | java.lang.Integer, type: int | java.jint | java.lang.Integer, message: str | java.lang.String, attributes: java.util.HashMap[java.lang.String, java.lang.Object], /) -> None: ...
    def getAttribute(self, key: str | java.lang.String, /) -> java.lang.Object | None: ...
    def getMessage(self) -> str: ...
    def getType(self) -> int: ...
    def getUniqueId(self) -> int: ...

class DrmInfo(java.lang.Object):
    @typing.overload
    def __init__(self, infoType: int | java.jint | java.lang.Integer, path: str | java.lang.String, mimeType: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, infoType: int | java.jint | java.lang.Integer, data: java.chaquopy.JavaArrayJByte, mimeType: str | java.lang.String, /) -> None: ...
    def get(self, key: str | java.lang.String, /) -> java.lang.Object | None: ...
    def getData(self) -> java.chaquopy.JavaArrayJByte: ...
    def getInfoType(self) -> int: ...
    def getMimeType(self) -> str: ...
    def iterator(self) -> java.util.Iterator[java.lang.Object]: ...
    def keyIterator(self) -> java.util.Iterator[java.lang.String]: ...
    def put(self, key: str | java.lang.String, value: java.lang.Object | int | bool | float | str, /) -> None: ...

class DrmInfoEvent(DrmEvent):
    TYPE_ACCOUNT_ALREADY_REGISTERED: typing.ClassVar[int] = ...
    TYPE_ALREADY_REGISTERED_BY_ANOTHER_ACCOUNT: typing.ClassVar[int] = ...
    TYPE_REMOVE_RIGHTS: typing.ClassVar[int] = ...
    TYPE_RIGHTS_INSTALLED: typing.ClassVar[int] = ...
    TYPE_RIGHTS_REMOVED: typing.ClassVar[int] = ...
    TYPE_WAIT_FOR_RIGHTS: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, uniqueId: int | java.jint | java.lang.Integer, type: int | java.jint | java.lang.Integer, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, uniqueId: int | java.jint | java.lang.Integer, type: int | java.jint | java.lang.Integer, message: str | java.lang.String, attributes: java.util.HashMap[java.lang.String, java.lang.Object], /) -> None: ...

class DrmInfoRequest(java.lang.Object):
    ACCOUNT_ID: typing.ClassVar[str] = ...
    SUBSCRIPTION_ID: typing.ClassVar[str] = ...
    TYPE_REGISTRATION_INFO: typing.ClassVar[int] = ...
    TYPE_RIGHTS_ACQUISITION_INFO: typing.ClassVar[int] = ...
    TYPE_RIGHTS_ACQUISITION_PROGRESS_INFO: typing.ClassVar[int] = ...
    TYPE_UNREGISTRATION_INFO: typing.ClassVar[int] = ...
    def __init__(self, infoType: int | java.jint | java.lang.Integer, mimeType: str | java.lang.String, /) -> None: ...
    def get(self, key: str | java.lang.String, /) -> java.lang.Object | None: ...
    def getInfoType(self) -> int: ...
    def getMimeType(self) -> str: ...
    def iterator(self) -> java.util.Iterator[java.lang.Object]: ...
    def keyIterator(self) -> java.util.Iterator[java.lang.String]: ...
    def put(self, key: str | java.lang.String, value: java.lang.Object | int | bool | float | str, /) -> None: ...

class DrmInfoStatus(java.lang.Object):
    STATUS_ERROR: typing.ClassVar[int] = ...
    STATUS_OK: typing.ClassVar[int] = ...
    data: ProcessedData = ...
    infoType: int = ...
    mimeType: str = ...
    statusCode: int = ...
    def __init__(self, statusCode: int | java.jint | java.lang.Integer, infoType: int | java.jint | java.lang.Integer, data: ProcessedData, mimeType: str | java.lang.String, /) -> None: ...

class DrmManagerClient(java.lang.AutoCloseable):
    ERROR_NONE: typing.ClassVar[int] = ...
    ERROR_UNKNOWN: typing.ClassVar[int] = ...
    def __init__(self, context: android.content.Context, /) -> None: ...
    def acquireDrmInfo(self, drmInfoRequest: DrmInfoRequest, /) -> DrmInfo: ...
    def acquireRights(self, drmInfoRequest: DrmInfoRequest, /) -> int: ...
    @typing.overload
    def canHandle(self, uri: android.net.Uri, mimeType: str | java.lang.String, /) -> bool: ...
    @typing.overload
    def canHandle(self, path: str | java.lang.String, mimeType: str | java.lang.String, /) -> bool: ...
    @typing.overload
    def checkRightsStatus(self, uri: android.net.Uri, /) -> int: ...
    @typing.overload
    def checkRightsStatus(self, path: str | java.lang.String, /) -> int: ...
    @typing.overload
    def checkRightsStatus(self, uri: android.net.Uri, action: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def checkRightsStatus(self, path: str | java.lang.String, action: int | java.jint | java.lang.Integer, /) -> int: ...
    def close(self) -> None: ...
    def closeConvertSession(self, convertId: int | java.jint | java.lang.Integer, /) -> DrmConvertedStatus: ...
    def convertData(self, convertId: int | java.jint | java.lang.Integer, inputData: java.chaquopy.JavaArrayJByte, /) -> DrmConvertedStatus: ...
    def finalize(self) -> None: ...
    def getAvailableDrmEngines(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getAvailableDrmSupportInfo(self) -> java.util.Collection[DrmSupportInfo]: ...
    @typing.overload
    def getConstraints(self, uri: android.net.Uri, action: int | java.jint | java.lang.Integer, /) -> android.content.ContentValues: ...
    @typing.overload
    def getConstraints(self, path: str | java.lang.String, action: int | java.jint | java.lang.Integer, /) -> android.content.ContentValues: ...
    @typing.overload
    def getDrmObjectType(self, uri: android.net.Uri, mimeType: str | java.lang.String, /) -> int: ...
    @typing.overload
    def getDrmObjectType(self, path: str | java.lang.String, mimeType: str | java.lang.String, /) -> int: ...
    @typing.overload
    def getMetadata(self, uri: android.net.Uri, /) -> android.content.ContentValues: ...
    @typing.overload
    def getMetadata(self, path: str | java.lang.String, /) -> android.content.ContentValues: ...
    @typing.overload
    def getOriginalMimeType(self, uri: android.net.Uri, /) -> str: ...
    @typing.overload
    def getOriginalMimeType(self, path: str | java.lang.String, /) -> str: ...
    def openConvertSession(self, mimeType: str | java.lang.String, /) -> int: ...
    def processDrmInfo(self, drmInfo: DrmInfo, /) -> int: ...
    def release(self) -> None: ...
    def removeAllRights(self) -> int: ...
    @typing.overload
    def removeRights(self, uri: android.net.Uri, /) -> int: ...
    @typing.overload
    def removeRights(self, path: str | java.lang.String, /) -> int: ...
    def saveRights(self, drmRights: DrmRights, rightsPath: str | java.lang.String, contentPath: str | java.lang.String, /) -> int: ...
    def setOnErrorListener(self, errorListener: DrmManagerClient.OnErrorListener, /) -> None: ...
    def setOnEventListener(self, eventListener: DrmManagerClient.OnEventListener, /) -> None: ...
    def setOnInfoListener(self, infoListener: DrmManagerClient.OnInfoListener, /) -> None: ...

    class OnInfoListener(java.lang.Object):
        def onInfo(self, arg1: DrmManagerClient, arg2: DrmInfoEvent, /) -> None: ...

    class OnEventListener(java.lang.Object):
        def onEvent(self, arg1: DrmManagerClient, arg2: DrmEvent, /) -> None: ...

    class OnErrorListener(java.lang.Object):
        def onError(self, arg1: DrmManagerClient, arg2: DrmErrorEvent, /) -> None: ...

class DrmRights(java.lang.Object):
    @typing.overload
    def __init__(self, data: ProcessedData, mimeType: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, rightsFile: java.io.File, mimeType: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, rightsFilePath: str | java.lang.String, mimeType: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, rightsFilePath: str | java.lang.String, mimeType: str | java.lang.String, accountId: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, rightsFilePath: str | java.lang.String, mimeType: str | java.lang.String, accountId: str | java.lang.String, subscriptionId: str | java.lang.String, /) -> None: ...
    def getAccountId(self) -> str: ...
    def getData(self) -> java.chaquopy.JavaArrayJByte: ...
    def getMimeType(self) -> str: ...
    def getSubscriptionId(self) -> str: ...

class DrmStore(java.lang.Object):
    def __init__(self) -> None: ...

    class RightsStatus(java.lang.Object):
        RIGHTS_EXPIRED: typing.ClassVar[int] = ...
        RIGHTS_INVALID: typing.ClassVar[int] = ...
        RIGHTS_NOT_ACQUIRED: typing.ClassVar[int] = ...
        RIGHTS_VALID: typing.ClassVar[int] = ...
        def __init__(self) -> None: ...

    class Playback(java.lang.Object):
        PAUSE: typing.ClassVar[int] = ...
        RESUME: typing.ClassVar[int] = ...
        START: typing.ClassVar[int] = ...
        STOP: typing.ClassVar[int] = ...
        def __init__(self) -> None: ...

    class DrmObjectType(java.lang.Object):
        CONTENT: typing.ClassVar[int] = ...
        RIGHTS_OBJECT: typing.ClassVar[int] = ...
        TRIGGER_OBJECT: typing.ClassVar[int] = ...
        UNKNOWN: typing.ClassVar[int] = ...
        def __init__(self) -> None: ...

    class ConstraintsColumns(java.lang.Object):
        EXTENDED_METADATA: typing.ClassVar[str] = ...
        LICENSE_AVAILABLE_TIME: typing.ClassVar[str] = ...
        LICENSE_EXPIRY_TIME: typing.ClassVar[str] = ...
        LICENSE_START_TIME: typing.ClassVar[str] = ...
        MAX_REPEAT_COUNT: typing.ClassVar[str] = ...
        REMAINING_REPEAT_COUNT: typing.ClassVar[str] = ...

    class Action(java.lang.Object):
        DEFAULT: typing.ClassVar[int] = ...
        DISPLAY: typing.ClassVar[int] = ...
        EXECUTE: typing.ClassVar[int] = ...
        OUTPUT: typing.ClassVar[int] = ...
        PLAY: typing.ClassVar[int] = ...
        PREVIEW: typing.ClassVar[int] = ...
        RINGTONE: typing.ClassVar[int] = ...
        TRANSFER: typing.ClassVar[int] = ...
        def __init__(self) -> None: ...

class DrmSupportInfo(java.lang.Object):
    def __init__(self) -> None: ...
    def addFileSuffix(self, fileSuffix: str | java.lang.String, /) -> None: ...
    def addMimeType(self, mimeType: str | java.lang.String, /) -> None: ...
    def equals(self, object: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getDescriprition(self) -> str: ...
    def getDescription(self) -> str: ...
    def getFileSuffixIterator(self) -> java.util.Iterator[java.lang.String]: ...
    def getMimeTypeIterator(self) -> java.util.Iterator[java.lang.String]: ...
    def hashCode(self) -> int: ...
    def setDescription(self, description: str | java.lang.String, /) -> None: ...

class DrmUtils(java.lang.Object):
    def __init__(self) -> None: ...
    @staticmethod
    def getExtendedMetadataParser(extendedMetadata: java.chaquopy.JavaArrayJByte, /) -> DrmUtils.ExtendedMetadataParser: ...

    class ExtendedMetadataParser(java.lang.Object):
        def get(self, key: str | java.lang.String, /) -> str: ...
        def iterator(self) -> java.util.Iterator[java.lang.String]: ...
        def keyIterator(self) -> java.util.Iterator[java.lang.String]: ...

class ProcessedData(java.lang.Object):
    def getAccountId(self) -> str: ...
    def getData(self) -> java.chaquopy.JavaArrayJByte: ...
    def getSubscriptionId(self) -> str: ...



import typing

import android.content
import android.net
import android.os
import java
import java.chaquopy
import java.io
import java.lang
import java.net
import java.nio
import java.security.cert
import java.time
import java.util
import java.util.concurrent
import javax.net.ssl

class BidirectionalStream(java.lang.Object):
    STREAM_PRIORITY_HIGHEST: typing.ClassVar[int] = ...
    STREAM_PRIORITY_IDLE: typing.ClassVar[int] = ...
    STREAM_PRIORITY_LOW: typing.ClassVar[int] = ...
    STREAM_PRIORITY_LOWEST: typing.ClassVar[int] = ...
    STREAM_PRIORITY_MEDIUM: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    def cancel(self) -> None: ...
    def flush(self) -> None: ...
    def getHeaders(self) -> HeaderBlock: ...
    def getHttpMethod(self) -> str: ...
    def getPriority(self) -> int: ...
    def getTrafficStatsTag(self) -> int: ...
    def getTrafficStatsUid(self) -> int: ...
    def hasTrafficStatsTag(self) -> bool: ...
    def hasTrafficStatsUid(self) -> bool: ...
    def isDelayRequestHeadersUntilFirstFlushEnabled(self) -> bool: ...
    def isDone(self) -> bool: ...
    def read(self, arg1: java.nio.ByteBuffer, /) -> None: ...
    def start(self) -> None: ...
    def write(self, arg1: java.nio.ByteBuffer, arg2: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

    class Callback(java.lang.Object):
        def onCanceled(self, arg1: BidirectionalStream, arg2: UrlResponseInfo, /) -> None: ...
        def onFailed(self, arg1: BidirectionalStream, arg2: UrlResponseInfo, arg3: HttpException, /) -> None: ...
        def onReadCompleted(self, arg1: BidirectionalStream, arg2: UrlResponseInfo, arg3: java.nio.ByteBuffer, arg4: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def onResponseHeadersReceived(self, arg1: BidirectionalStream, arg2: UrlResponseInfo, /) -> None: ...
        def onResponseTrailersReceived(self, arg1: BidirectionalStream, arg2: UrlResponseInfo, arg3: HeaderBlock, /) -> None: ...
        def onStreamReady(self, arg1: BidirectionalStream, /) -> None: ...
        def onSucceeded(self, arg1: BidirectionalStream, arg2: UrlResponseInfo, /) -> None: ...
        def onWriteCompleted(self, arg1: BidirectionalStream, arg2: UrlResponseInfo, arg3: java.nio.ByteBuffer, arg4: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def addHeader(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> BidirectionalStream.Builder: ...
        def build(self) -> BidirectionalStream: ...
        def setDelayRequestHeadersUntilFirstFlushEnabled(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> BidirectionalStream.Builder: ...
        def setHttpMethod(self, arg1: str | java.lang.String, /) -> BidirectionalStream.Builder: ...
        def setPriority(self, arg1: int | java.jint | java.lang.Integer, /) -> BidirectionalStream.Builder: ...
        def setTrafficStatsTag(self, arg1: int | java.jint | java.lang.Integer, /) -> BidirectionalStream.Builder: ...
        def setTrafficStatsUid(self, arg1: int | java.jint | java.lang.Integer, /) -> BidirectionalStream.Builder: ...

class CallbackException(HttpException):
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...

class ConnectionMigrationOptions(java.lang.Object):
    MIGRATION_OPTION_DISABLED: typing.ClassVar[int] = ...
    MIGRATION_OPTION_ENABLED: typing.ClassVar[int] = ...
    MIGRATION_OPTION_UNSPECIFIED: typing.ClassVar[int] = ...
    def getAllowNonDefaultNetworkUsage(self) -> int: ...
    def getDefaultNetworkMigration(self) -> int: ...
    def getPathDegradationMigration(self) -> int: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> ConnectionMigrationOptions: ...
        def setAllowNonDefaultNetworkUsage(self, state: int | java.jint | java.lang.Integer, /) -> ConnectionMigrationOptions.Builder: ...
        def setDefaultNetworkMigration(self, state: int | java.jint | java.lang.Integer, /) -> ConnectionMigrationOptions.Builder: ...
        def setPathDegradationMigration(self, state: int | java.jint | java.lang.Integer, /) -> ConnectionMigrationOptions.Builder: ...

class DnsOptions(java.lang.Object):
    DNS_OPTION_DISABLED: typing.ClassVar[int] = ...
    DNS_OPTION_ENABLED: typing.ClassVar[int] = ...
    DNS_OPTION_UNSPECIFIED: typing.ClassVar[int] = ...
    def getPersistHostCache(self) -> int: ...
    def getPersistHostCachePeriod(self) -> java.time.Duration | None: ...
    def getPreestablishConnectionsToStaleDnsResults(self) -> int: ...
    def getStaleDns(self) -> int: ...
    def getStaleDnsOptions(self) -> DnsOptions.StaleDnsOptions | None: ...
    def getUseHttpStackDnsResolver(self) -> int: ...

    class StaleDnsOptions(java.lang.Object):
        def getAllowCrossNetworkUsage(self) -> int: ...
        def getFreshLookupTimeout(self) -> java.time.Duration: ...
        def getMaxExpiredDelay(self) -> java.time.Duration: ...
        def getUseStaleOnNameNotResolved(self) -> int: ...

        class Builder(java.lang.Object):
            def __init__(self) -> None: ...
            def build(self) -> DnsOptions.StaleDnsOptions: ...
            def setAllowCrossNetworkUsage(self, state: int | java.jint | java.lang.Integer, /) -> DnsOptions.StaleDnsOptions.Builder: ...
            def setFreshLookupTimeout(self, freshLookupTimeout: java.time.Duration, /) -> DnsOptions.StaleDnsOptions.Builder: ...
            def setMaxExpiredDelay(self, maxExpiredDelay: java.time.Duration, /) -> DnsOptions.StaleDnsOptions.Builder: ...
            def setUseStaleOnNameNotResolved(self, state: int | java.jint | java.lang.Integer, /) -> DnsOptions.StaleDnsOptions.Builder: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> DnsOptions: ...
        def setPersistHostCache(self, state: int | java.jint | java.lang.Integer, /) -> DnsOptions.Builder: ...
        def setPersistHostCachePeriod(self, persistHostCachePeriod: java.time.Duration, /) -> DnsOptions.Builder: ...
        def setPreestablishConnectionsToStaleDnsResults(self, state: int | java.jint | java.lang.Integer, /) -> DnsOptions.Builder: ...
        def setStaleDns(self, state: int | java.jint | java.lang.Integer, /) -> DnsOptions.Builder: ...
        def setStaleDnsOptions(self, staleDnsOptions: DnsOptions.StaleDnsOptions, /) -> DnsOptions.Builder: ...
        def setUseHttpStackDnsResolver(self, state: int | java.jint | java.lang.Integer, /) -> DnsOptions.Builder: ...

class HeaderBlock(java.lang.Object):
    def __init__(self) -> None: ...
    def getAsList(self) -> java.util.List[java.util.Map.Entry[java.lang.String, java.lang.String]]: ...
    def getAsMap(self) -> java.util.Map[java.lang.String, java.util.List[java.lang.String]]: ...

class HttpEngine(java.lang.Object):
    def bindToNetwork(self, network: android.net.Network, /) -> None: ...
    def createUrlStreamHandlerFactory(self) -> java.net.URLStreamHandlerFactory: ...
    @staticmethod
    def getVersionString() -> str: ...
    def newBidirectionalStreamBuilder(self, arg1: str | java.lang.String, arg2: java.util.concurrent.Executor, arg3: BidirectionalStream.Callback, /) -> BidirectionalStream.Builder: ...
    def newUrlRequestBuilder(self, arg1: str | java.lang.String, arg2: java.util.concurrent.Executor, arg3: UrlRequest.Callback, /) -> UrlRequest.Builder: ...
    def openConnection(self, arg1: java.net.URL, /) -> java.net.URLConnection: ...
    def shutdown(self) -> None: ...

    class Builder(java.lang.Object):
        HTTP_CACHE_DISABLED: typing.ClassVar[int] = ...
        HTTP_CACHE_DISK: typing.ClassVar[int] = ...
        HTTP_CACHE_DISK_NO_HTTP: typing.ClassVar[int] = ...
        HTTP_CACHE_IN_MEMORY: typing.ClassVar[int] = ...
        def __init__(self, context: android.content.Context, /) -> None: ...
        def addPublicKeyPins(self, hostName: str | java.lang.String, pinsSha256: java.util.Set[java.chaquopy.JavaArrayJByte], includeSubdomains: bool | java.jboolean | java.lang.Boolean, expirationInstant: java.time.Instant, /) -> HttpEngine.Builder: ...
        def addQuicHint(self, host: str | java.lang.String, port: int | java.jint | java.lang.Integer, alternatePort: int | java.jint | java.lang.Integer, /) -> HttpEngine.Builder: ...
        def build(self) -> HttpEngine: ...
        def getDefaultUserAgent(self) -> str: ...
        def setConnectionMigrationOptions(self, connectionMigrationOptions: ConnectionMigrationOptions, /) -> HttpEngine.Builder: ...
        def setDnsOptions(self, dnsOptions: DnsOptions, /) -> HttpEngine.Builder: ...
        def setEnableBrotli(self, value: bool | java.jboolean | java.lang.Boolean, /) -> HttpEngine.Builder: ...
        def setEnableHttp2(self, value: bool | java.jboolean | java.lang.Boolean, /) -> HttpEngine.Builder: ...
        def setEnableHttpCache(self, cacheMode: int | java.jint | java.lang.Integer, maxSize: int | java.jlong | java.lang.Long, /) -> HttpEngine.Builder: ...
        def setEnablePublicKeyPinningBypassForLocalTrustAnchors(self, value: bool | java.jboolean | java.lang.Boolean, /) -> HttpEngine.Builder: ...
        def setEnableQuic(self, value: bool | java.jboolean | java.lang.Boolean, /) -> HttpEngine.Builder: ...
        def setQuicOptions(self, quicOptions: QuicOptions, /) -> HttpEngine.Builder: ...
        def setStoragePath(self, value: str | java.lang.String, /) -> HttpEngine.Builder: ...
        def setUserAgent(self, userAgent: str | java.lang.String, /) -> HttpEngine.Builder: ...

class HttpException(java.io.IOException):
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...

class HttpResponseCache(java.io.Closeable, java.net.ResponseCache):
    def close(self) -> None: ...
    def delete(self) -> None: ...
    def flush(self) -> None: ...
    def get(self, uri: java.net.URI, requestMethod: str | java.lang.String, requestHeaders: java.util.Map[java.lang.String, java.util.List[java.lang.String]], /) -> java.net.CacheResponse: ...
    def getHitCount(self) -> int: ...
    @staticmethod
    def getInstalled() -> HttpResponseCache: ...
    def getNetworkCount(self) -> int: ...
    def getRequestCount(self) -> int: ...
    @staticmethod
    def install(directory: java.io.File, maxSize: int | java.jlong | java.lang.Long, /) -> HttpResponseCache: ...
    def maxSize(self) -> int: ...
    def put(self, uri: java.net.URI, urlConnection: java.net.URLConnection, /) -> java.net.CacheRequest: ...
    def size(self) -> int: ...

class InlineExecutionProhibitedException(java.util.concurrent.RejectedExecutionException):
    def __init__(self) -> None: ...

class NetworkException(HttpException):
    ERROR_ADDRESS_UNREACHABLE: typing.ClassVar[int] = ...
    ERROR_CONNECTION_CLOSED: typing.ClassVar[int] = ...
    ERROR_CONNECTION_REFUSED: typing.ClassVar[int] = ...
    ERROR_CONNECTION_RESET: typing.ClassVar[int] = ...
    ERROR_CONNECTION_TIMED_OUT: typing.ClassVar[int] = ...
    ERROR_HOSTNAME_NOT_RESOLVED: typing.ClassVar[int] = ...
    ERROR_INTERNET_DISCONNECTED: typing.ClassVar[int] = ...
    ERROR_NETWORK_CHANGED: typing.ClassVar[int] = ...
    ERROR_OTHER: typing.ClassVar[int] = ...
    ERROR_QUIC_PROTOCOL_FAILED: typing.ClassVar[int] = ...
    ERROR_TIMED_OUT: typing.ClassVar[int] = ...
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...
    def getErrorCode(self) -> int: ...
    def isImmediatelyRetryable(self) -> bool: ...

class QuicException(NetworkException):
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...

class QuicOptions(java.lang.Object):
    def getAllowedQuicHosts(self) -> java.util.Set[java.lang.String]: ...
    def getHandshakeUserAgent(self) -> str | None: ...
    def getIdleConnectionTimeout(self) -> java.time.Duration | None: ...
    def getInMemoryServerConfigsCacheSize(self) -> int: ...
    def hasInMemoryServerConfigsCacheSize(self) -> bool: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def addAllowedQuicHost(self, quicHost: str | java.lang.String, /) -> QuicOptions.Builder: ...
        def build(self) -> QuicOptions: ...
        def setHandshakeUserAgent(self, handshakeUserAgent: str | java.lang.String, /) -> QuicOptions.Builder: ...
        def setIdleConnectionTimeout(self, idleConnectionTimeout: java.time.Duration, /) -> QuicOptions.Builder: ...
        def setInMemoryServerConfigsCacheSize(self, inMemoryServerConfigsCacheSize: int | java.jint | java.lang.Integer, /) -> QuicOptions.Builder: ...

class SslCertificate(java.lang.Object):
    @typing.overload
    def __init__(self, certificate: java.security.cert.X509Certificate, /) -> None: ...
    @typing.overload
    def __init__(self, issuedTo: str | java.lang.String, issuedBy: str | java.lang.String, validNotBefore: str | java.lang.String, validNotAfter: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, issuedTo: str | java.lang.String, issuedBy: str | java.lang.String, validNotBefore: java.util.Date, validNotAfter: java.util.Date, /) -> None: ...
    def getIssuedBy(self) -> SslCertificate.DName | None: ...
    def getIssuedTo(self) -> SslCertificate.DName | None: ...
    def getValidNotAfter(self) -> str: ...
    def getValidNotAfterDate(self) -> java.util.Date: ...
    def getValidNotBefore(self) -> str: ...
    def getValidNotBeforeDate(self) -> java.util.Date: ...
    def getX509Certificate(self) -> java.security.cert.X509Certificate | None: ...
    @staticmethod
    def restoreState(bundle: android.os.Bundle, /) -> SslCertificate | None: ...
    @staticmethod
    def saveState(certificate: SslCertificate, /) -> android.os.Bundle | None: ...
    def toString(self) -> str: ...

    class DName(java.lang.Object):
        def __init__(self, this_0: SslCertificate, dName: str | java.lang.String, /) -> None: ...
        def getCName(self) -> str: ...
        def getDName(self) -> str: ...
        def getOName(self) -> str: ...
        def getUName(self) -> str: ...

class SslError(java.lang.Object):
    SSL_DATE_INVALID: typing.ClassVar[int] = ...
    SSL_EXPIRED: typing.ClassVar[int] = ...
    SSL_IDMISMATCH: typing.ClassVar[int] = ...
    SSL_INVALID: typing.ClassVar[int] = ...
    SSL_MAX_ERROR: typing.ClassVar[int] = ...
    SSL_NOTYETVALID: typing.ClassVar[int] = ...
    SSL_UNTRUSTED: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, error: int | java.jint | java.lang.Integer, certificate: SslCertificate, /) -> None: ...
    @typing.overload
    def __init__(self, error: int | java.jint | java.lang.Integer, certificate: java.security.cert.X509Certificate, /) -> None: ...
    @typing.overload
    def __init__(self, error: int | java.jint | java.lang.Integer, certificate: SslCertificate, url: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, error: int | java.jint | java.lang.Integer, certificate: java.security.cert.X509Certificate, url: str | java.lang.String, /) -> None: ...
    def addError(self, error: int | java.jint | java.lang.Integer, /) -> bool: ...
    def getCertificate(self) -> SslCertificate: ...
    def getPrimaryError(self) -> int: ...
    def getUrl(self) -> str: ...
    def hasError(self, error: int | java.jint | java.lang.Integer, /) -> bool: ...
    def toString(self) -> str: ...

class UploadDataProvider(java.io.Closeable):
    def __init__(self) -> None: ...
    def close(self) -> None: ...
    def getLength(self) -> int: ...
    def read(self, arg1: UploadDataSink, arg2: java.nio.ByteBuffer, /) -> None: ...
    def rewind(self, arg1: UploadDataSink, /) -> None: ...

class UploadDataSink(java.lang.Object):
    def __init__(self) -> None: ...
    def onReadError(self, arg1: java.lang.Exception, /) -> None: ...
    def onReadSucceeded(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def onRewindError(self, arg1: java.lang.Exception, /) -> None: ...
    def onRewindSucceeded(self) -> None: ...

class UrlRequest(java.lang.Object):
    REQUEST_PRIORITY_HIGHEST: typing.ClassVar[int] = ...
    REQUEST_PRIORITY_IDLE: typing.ClassVar[int] = ...
    REQUEST_PRIORITY_LOW: typing.ClassVar[int] = ...
    REQUEST_PRIORITY_LOWEST: typing.ClassVar[int] = ...
    REQUEST_PRIORITY_MEDIUM: typing.ClassVar[int] = ...
    def cancel(self) -> None: ...
    def followRedirect(self) -> None: ...
    def getHeaders(self) -> HeaderBlock: ...
    def getHttpMethod(self) -> str | None: ...
    def getPriority(self) -> int: ...
    def getStatus(self, arg1: UrlRequest.StatusListener, /) -> None: ...
    def getTrafficStatsTag(self) -> int: ...
    def getTrafficStatsUid(self) -> int: ...
    def hasTrafficStatsTag(self) -> bool: ...
    def hasTrafficStatsUid(self) -> bool: ...
    def isCacheDisabled(self) -> bool: ...
    def isDirectExecutorAllowed(self) -> bool: ...
    def isDone(self) -> bool: ...
    def read(self, arg1: java.nio.ByteBuffer, /) -> None: ...
    def start(self) -> None: ...

    class StatusListener(java.lang.Object):
        def onStatus(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...

    class Status(java.lang.Object):
        CONNECTING: typing.ClassVar[int] = ...
        DOWNLOADING_PAC_FILE: typing.ClassVar[int] = ...
        ESTABLISHING_PROXY_TUNNEL: typing.ClassVar[int] = ...
        IDLE: typing.ClassVar[int] = ...
        INVALID: typing.ClassVar[int] = ...
        READING_RESPONSE: typing.ClassVar[int] = ...
        RESOLVING_HOST: typing.ClassVar[int] = ...
        RESOLVING_HOST_IN_PAC_FILE: typing.ClassVar[int] = ...
        RESOLVING_PROXY_FOR_URL: typing.ClassVar[int] = ...
        SENDING_REQUEST: typing.ClassVar[int] = ...
        SSL_HANDSHAKE: typing.ClassVar[int] = ...
        WAITING_FOR_AVAILABLE_SOCKET: typing.ClassVar[int] = ...
        WAITING_FOR_CACHE: typing.ClassVar[int] = ...
        WAITING_FOR_DELEGATE: typing.ClassVar[int] = ...
        WAITING_FOR_RESPONSE: typing.ClassVar[int] = ...
        WAITING_FOR_STALLED_SOCKET_POOL: typing.ClassVar[int] = ...

    class Callback(java.lang.Object):
        def onCanceled(self, arg1: UrlRequest, arg2: UrlResponseInfo, /) -> None: ...
        def onFailed(self, arg1: UrlRequest, arg2: UrlResponseInfo, arg3: HttpException, /) -> None: ...
        def onReadCompleted(self, arg1: UrlRequest, arg2: UrlResponseInfo, arg3: java.nio.ByteBuffer, /) -> None: ...
        def onRedirectReceived(self, arg1: UrlRequest, arg2: UrlResponseInfo, arg3: str | java.lang.String, /) -> None: ...
        def onResponseStarted(self, arg1: UrlRequest, arg2: UrlResponseInfo, /) -> None: ...
        def onSucceeded(self, arg1: UrlRequest, arg2: UrlResponseInfo, /) -> None: ...

    class Builder(java.lang.Object):
        def addHeader(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> UrlRequest.Builder: ...
        def bindToNetwork(self, arg1: android.net.Network, /) -> UrlRequest.Builder: ...
        def build(self) -> UrlRequest: ...
        def setCacheDisabled(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> UrlRequest.Builder: ...
        def setDirectExecutorAllowed(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> UrlRequest.Builder: ...
        def setHttpMethod(self, arg1: str | java.lang.String, /) -> UrlRequest.Builder: ...
        def setPriority(self, arg1: int | java.jint | java.lang.Integer, /) -> UrlRequest.Builder: ...
        def setTrafficStatsTag(self, arg1: int | java.jint | java.lang.Integer, /) -> UrlRequest.Builder: ...
        def setTrafficStatsUid(self, arg1: int | java.jint | java.lang.Integer, /) -> UrlRequest.Builder: ...
        def setUploadDataProvider(self, arg1: UploadDataProvider, arg2: java.util.concurrent.Executor, /) -> UrlRequest.Builder: ...

class UrlResponseInfo(java.lang.Object):
    def __init__(self) -> None: ...
    def getHeaders(self) -> HeaderBlock: ...
    def getHttpStatusCode(self) -> int: ...
    def getHttpStatusText(self) -> str: ...
    def getNegotiatedProtocol(self) -> str: ...
    def getReceivedByteCount(self) -> int: ...
    def getUrl(self) -> str: ...
    def getUrlChain(self) -> java.util.List[java.lang.String]: ...
    def wasCached(self) -> bool: ...

class X509TrustManagerExtensions(java.lang.Object):
    def __init__(self, tm: javax.net.ssl.X509TrustManager, /) -> None: ...
    @typing.overload
    def checkServerTrusted(self, chain: java.chaquopy.JavaArray[java.security.cert.X509Certificate], authType: str | java.lang.String, host: str | java.lang.String, /) -> java.util.List[java.security.cert.X509Certificate]: ...
    @typing.overload
    def checkServerTrusted(self, chain: java.chaquopy.JavaArray[java.security.cert.X509Certificate], ocspData: java.chaquopy.JavaArrayJByte, tlsSctData: java.chaquopy.JavaArrayJByte, authType: str | java.lang.String, host: str | java.lang.String, /) -> java.util.List[java.security.cert.X509Certificate]: ...
    def isSameTrustConfiguration(self, hostname1: str | java.lang.String, hostname2: str | java.lang.String, /) -> bool: ...
    def isUserAddedCertificate(self, cert: java.security.cert.X509Certificate, /) -> bool: ...



import typing

import java
import java.chaquopy
import java.io
import java.lang
import java.nio
import java.security
import java.security.cert
import java.security.spec
import javax.security.auth

class AEADBadTagException(BadPaddingException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, msg: str | java.lang.String, /) -> None: ...

class BadPaddingException(java.security.GeneralSecurityException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, msg: str | java.lang.String, /) -> None: ...

class Cipher(java.lang.Object):
    DECRYPT_MODE: typing.ClassVar[int] = ...
    ENCRYPT_MODE: typing.ClassVar[int] = ...
    PRIVATE_KEY: typing.ClassVar[int] = ...
    PUBLIC_KEY: typing.ClassVar[int] = ...
    SECRET_KEY: typing.ClassVar[int] = ...
    UNWRAP_MODE: typing.ClassVar[int] = ...
    WRAP_MODE: typing.ClassVar[int] = ...
    def __init__(self, cipherSpi: CipherSpi, provider: java.security.Provider, transformation: str | java.lang.String, /) -> None: ...
    @typing.overload
    def doFinal(self) -> java.chaquopy.JavaArrayJByte: ...
    @typing.overload
    def doFinal(self, input: java.chaquopy.JavaArrayJByte, /) -> java.chaquopy.JavaArrayJByte: ...
    @typing.overload
    def doFinal(self, input: java.nio.ByteBuffer, output: java.nio.ByteBuffer, /) -> int: ...
    @typing.overload
    def doFinal(self, output: java.chaquopy.JavaArrayJByte, outputOffset: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def doFinal(self, input: java.chaquopy.JavaArrayJByte, inputOffset: int | java.jint | java.lang.Integer, inputLen: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJByte: ...
    @typing.overload
    def doFinal(self, input: java.chaquopy.JavaArrayJByte, inputOffset: int | java.jint | java.lang.Integer, inputLen: int | java.jint | java.lang.Integer, output: java.chaquopy.JavaArrayJByte, /) -> int: ...
    @typing.overload
    def doFinal(self, input: java.chaquopy.JavaArrayJByte, inputOffset: int | java.jint | java.lang.Integer, inputLen: int | java.jint | java.lang.Integer, output: java.chaquopy.JavaArrayJByte, outputOffset: int | java.jint | java.lang.Integer, /) -> int: ...
    def getAlgorithm(self) -> str: ...
    def getBlockSize(self) -> int: ...
    def getExemptionMechanism(self) -> ExemptionMechanism: ...
    def getIV(self) -> java.chaquopy.JavaArrayJByte: ...
    @typing.overload
    @staticmethod
    def getInstance(transformation: str | java.lang.String, /) -> Cipher: ...
    @typing.overload
    @staticmethod
    def getInstance(transformation: str | java.lang.String, provider: str | java.lang.String, /) -> Cipher: ...
    @typing.overload
    @staticmethod
    def getInstance(transformation: str | java.lang.String, provider: java.security.Provider, /) -> Cipher: ...
    @staticmethod
    def getMaxAllowedKeyLength(transformation: str | java.lang.String, /) -> int: ...
    @staticmethod
    def getMaxAllowedParameterSpec(transformation: str | java.lang.String, /) -> java.security.spec.AlgorithmParameterSpec: ...
    def getOutputSize(self, inputLen: int | java.jint | java.lang.Integer, /) -> int: ...
    def getParameters(self) -> java.security.AlgorithmParameters: ...
    def getProvider(self) -> java.security.Provider: ...
    @typing.overload
    def init(self, opmode: int | java.jint | java.lang.Integer, key: java.security.Key, /) -> None: ...
    @typing.overload
    def init(self, opmode: int | java.jint | java.lang.Integer, certificate: java.security.cert.Certificate, /) -> None: ...
    @typing.overload
    def init(self, opmode: int | java.jint | java.lang.Integer, key: java.security.Key, params: java.security.AlgorithmParameters, /) -> None: ...
    @typing.overload
    def init(self, opmode: int | java.jint | java.lang.Integer, key: java.security.Key, random: java.security.SecureRandom, /) -> None: ...
    @typing.overload
    def init(self, opmode: int | java.jint | java.lang.Integer, key: java.security.Key, params: java.security.spec.AlgorithmParameterSpec, /) -> None: ...
    @typing.overload
    def init(self, opmode: int | java.jint | java.lang.Integer, certificate: java.security.cert.Certificate, random: java.security.SecureRandom, /) -> None: ...
    @typing.overload
    def init(self, opmode: int | java.jint | java.lang.Integer, key: java.security.Key, params: java.security.AlgorithmParameters, random: java.security.SecureRandom, /) -> None: ...
    @typing.overload
    def init(self, opmode: int | java.jint | java.lang.Integer, key: java.security.Key, params: java.security.spec.AlgorithmParameterSpec, random: java.security.SecureRandom, /) -> None: ...
    def unwrap(self, wrappedKey: java.chaquopy.JavaArrayJByte, wrappedKeyAlgorithm: str | java.lang.String, wrappedKeyType: int | java.jint | java.lang.Integer, /) -> java.security.Key: ...
    @typing.overload
    def update(self, input: java.chaquopy.JavaArrayJByte, /) -> java.chaquopy.JavaArrayJByte: ...
    @typing.overload
    def update(self, input: java.nio.ByteBuffer, output: java.nio.ByteBuffer, /) -> int: ...
    @typing.overload
    def update(self, input: java.chaquopy.JavaArrayJByte, inputOffset: int | java.jint | java.lang.Integer, inputLen: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJByte: ...
    @typing.overload
    def update(self, input: java.chaquopy.JavaArrayJByte, inputOffset: int | java.jint | java.lang.Integer, inputLen: int | java.jint | java.lang.Integer, output: java.chaquopy.JavaArrayJByte, /) -> int: ...
    @typing.overload
    def update(self, input: java.chaquopy.JavaArrayJByte, inputOffset: int | java.jint | java.lang.Integer, inputLen: int | java.jint | java.lang.Integer, output: java.chaquopy.JavaArrayJByte, outputOffset: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def updateAAD(self, src: java.nio.ByteBuffer, /) -> None: ...
    @typing.overload
    def updateAAD(self, src: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def updateAAD(self, src: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    def wrap(self, key: java.security.Key, /) -> java.chaquopy.JavaArrayJByte: ...

class CipherInputStream(java.io.FilterInputStream):
    @typing.overload
    def __init__(self, is_: java.io.InputStream, /) -> None: ...
    @typing.overload
    def __init__(self, is_: java.io.InputStream, c: Cipher, /) -> None: ...
    def available(self) -> int: ...
    def close(self) -> None: ...
    def markSupported(self) -> bool: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, /) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
    def skip(self, n: int | java.jlong | java.lang.Long, /) -> int: ...

class CipherOutputStream(java.io.FilterOutputStream):
    @typing.overload
    def __init__(self, os: java.io.OutputStream, /) -> None: ...
    @typing.overload
    def __init__(self, os: java.io.OutputStream, c: Cipher, /) -> None: ...
    def close(self) -> None: ...
    def flush(self) -> None: ...
    @typing.overload
    def write(self, b: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def write(self, b: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def write(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...

class CipherSpi(java.lang.Object):
    def __init__(self) -> None: ...
    @typing.overload
    def engineDoFinal(self, input: java.nio.ByteBuffer, output: java.nio.ByteBuffer, /) -> int: ...
    @typing.overload
    def engineDoFinal(self, arg1: java.chaquopy.JavaArrayJByte, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJByte: ...
    @typing.overload
    def engineDoFinal(self, arg1: java.chaquopy.JavaArrayJByte, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJByte, arg5: int | java.jint | java.lang.Integer, /) -> int: ...
    def engineGetBlockSize(self) -> int: ...
    def engineGetIV(self) -> java.chaquopy.JavaArrayJByte: ...
    def engineGetKeySize(self, key: java.security.Key, /) -> int: ...
    def engineGetOutputSize(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    def engineGetParameters(self) -> java.security.AlgorithmParameters: ...
    @typing.overload
    def engineInit(self, arg1: int | java.jint | java.lang.Integer, arg2: java.security.Key, arg3: java.security.SecureRandom, /) -> None: ...
    @typing.overload
    def engineInit(self, arg1: int | java.jint | java.lang.Integer, arg2: java.security.Key, arg3: java.security.AlgorithmParameters, arg4: java.security.SecureRandom, /) -> None: ...
    @typing.overload
    def engineInit(self, arg1: int | java.jint | java.lang.Integer, arg2: java.security.Key, arg3: java.security.spec.AlgorithmParameterSpec, arg4: java.security.SecureRandom, /) -> None: ...
    def engineSetMode(self, arg1: str | java.lang.String, /) -> None: ...
    def engineSetPadding(self, arg1: str | java.lang.String, /) -> None: ...
    def engineUnwrap(self, wrappedKey: java.chaquopy.JavaArrayJByte, wrappedKeyAlgorithm: str | java.lang.String, wrappedKeyType: int | java.jint | java.lang.Integer, /) -> java.security.Key: ...
    @typing.overload
    def engineUpdate(self, input: java.nio.ByteBuffer, output: java.nio.ByteBuffer, /) -> int: ...
    @typing.overload
    def engineUpdate(self, arg1: java.chaquopy.JavaArrayJByte, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJByte: ...
    @typing.overload
    def engineUpdate(self, arg1: java.chaquopy.JavaArrayJByte, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJByte, arg5: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def engineUpdateAAD(self, src: java.nio.ByteBuffer, /) -> None: ...
    @typing.overload
    def engineUpdateAAD(self, src: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...
    def engineWrap(self, key: java.security.Key, /) -> java.chaquopy.JavaArrayJByte: ...

class EncryptedPrivateKeyInfo(java.lang.Object):
    @typing.overload
    def __init__(self, encoded: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def __init__(self, algName: str | java.lang.String, encryptedData: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def __init__(self, algParams: java.security.AlgorithmParameters, encryptedData: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def getAlgName(self) -> str: ...
    def getAlgParameters(self) -> java.security.AlgorithmParameters: ...
    def getEncoded(self) -> java.chaquopy.JavaArrayJByte: ...
    def getEncryptedData(self) -> java.chaquopy.JavaArrayJByte: ...
    @typing.overload
    def getKeySpec(self, decryptKey: java.security.Key, /) -> java.security.spec.PKCS8EncodedKeySpec: ...
    @typing.overload
    def getKeySpec(self, cipher: Cipher, /) -> java.security.spec.PKCS8EncodedKeySpec: ...
    @typing.overload
    def getKeySpec(self, decryptKey: java.security.Key, providerName: str | java.lang.String, /) -> java.security.spec.PKCS8EncodedKeySpec: ...
    @typing.overload
    def getKeySpec(self, decryptKey: java.security.Key, provider: java.security.Provider, /) -> java.security.spec.PKCS8EncodedKeySpec: ...

class ExemptionMechanism(java.lang.Object):
    def __init__(self, exmechSpi: ExemptionMechanismSpi, provider: java.security.Provider, mechanism: str | java.lang.String, /) -> None: ...
    @typing.overload
    def genExemptionBlob(self) -> java.chaquopy.JavaArrayJByte: ...
    @typing.overload
    def genExemptionBlob(self, output: java.chaquopy.JavaArrayJByte, /) -> int: ...
    @typing.overload
    def genExemptionBlob(self, output: java.chaquopy.JavaArrayJByte, outputOffset: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    @staticmethod
    def getInstance(algorithm: str | java.lang.String, /) -> ExemptionMechanism: ...
    @typing.overload
    @staticmethod
    def getInstance(algorithm: str | java.lang.String, provider: str | java.lang.String, /) -> ExemptionMechanism: ...
    @typing.overload
    @staticmethod
    def getInstance(algorithm: str | java.lang.String, provider: java.security.Provider, /) -> ExemptionMechanism: ...
    def getName(self) -> str: ...
    def getOutputSize(self, inputLen: int | java.jint | java.lang.Integer, /) -> int: ...
    def getProvider(self) -> java.security.Provider: ...
    @typing.overload
    def init(self, key: java.security.Key, /) -> None: ...
    @typing.overload
    def init(self, key: java.security.Key, params: java.security.AlgorithmParameters, /) -> None: ...
    @typing.overload
    def init(self, key: java.security.Key, params: java.security.spec.AlgorithmParameterSpec, /) -> None: ...
    def isCryptoAllowed(self, key: java.security.Key, /) -> bool: ...

class ExemptionMechanismException(java.security.GeneralSecurityException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, msg: str | java.lang.String, /) -> None: ...

class ExemptionMechanismSpi(java.lang.Object):
    def __init__(self) -> None: ...
    @typing.overload
    def engineGenExemptionBlob(self) -> java.chaquopy.JavaArrayJByte: ...
    @typing.overload
    def engineGenExemptionBlob(self, arg1: java.chaquopy.JavaArrayJByte, arg2: int | java.jint | java.lang.Integer, /) -> int: ...
    def engineGetOutputSize(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def engineInit(self, arg1: java.security.Key, /) -> None: ...
    @typing.overload
    def engineInit(self, arg1: java.security.Key, arg2: java.security.AlgorithmParameters, /) -> None: ...
    @typing.overload
    def engineInit(self, arg1: java.security.Key, arg2: java.security.spec.AlgorithmParameterSpec, /) -> None: ...

class IllegalBlockSizeException(java.security.GeneralSecurityException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, msg: str | java.lang.String, /) -> None: ...

class KeyAgreement(java.lang.Object):
    def __init__(self, keyAgreeSpi: KeyAgreementSpi, provider: java.security.Provider, algorithm: str | java.lang.String, /) -> None: ...
    def doPhase(self, key: java.security.Key, lastPhase: bool | java.jboolean | java.lang.Boolean, /) -> java.security.Key: ...
    @typing.overload
    def generateSecret(self) -> java.chaquopy.JavaArrayJByte: ...
    @typing.overload
    def generateSecret(self, algorithm: str | java.lang.String, /) -> SecretKey: ...
    @typing.overload
    def generateSecret(self, sharedSecret: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, /) -> int: ...
    def getAlgorithm(self) -> str: ...
    @typing.overload
    @staticmethod
    def getInstance(algorithm: str | java.lang.String, /) -> KeyAgreement: ...
    @typing.overload
    @staticmethod
    def getInstance(algorithm: str | java.lang.String, provider: str | java.lang.String, /) -> KeyAgreement: ...
    @typing.overload
    @staticmethod
    def getInstance(algorithm: str | java.lang.String, provider: java.security.Provider, /) -> KeyAgreement: ...
    def getProvider(self) -> java.security.Provider: ...
    @typing.overload
    def init(self, key: java.security.Key, /) -> None: ...
    @typing.overload
    def init(self, key: java.security.Key, random: java.security.SecureRandom, /) -> None: ...
    @typing.overload
    def init(self, key: java.security.Key, params: java.security.spec.AlgorithmParameterSpec, /) -> None: ...
    @typing.overload
    def init(self, key: java.security.Key, params: java.security.spec.AlgorithmParameterSpec, random: java.security.SecureRandom, /) -> None: ...

class KeyAgreementSpi(java.lang.Object):
    def __init__(self) -> None: ...
    def engineDoPhase(self, arg1: java.security.Key, arg2: bool | java.jboolean | java.lang.Boolean, /) -> java.security.Key: ...
    @typing.overload
    def engineGenerateSecret(self) -> java.chaquopy.JavaArrayJByte: ...
    @typing.overload
    def engineGenerateSecret(self, arg1: str | java.lang.String, /) -> SecretKey: ...
    @typing.overload
    def engineGenerateSecret(self, arg1: java.chaquopy.JavaArrayJByte, arg2: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def engineInit(self, arg1: java.security.Key, arg2: java.security.SecureRandom, /) -> None: ...
    @typing.overload
    def engineInit(self, arg1: java.security.Key, arg2: java.security.spec.AlgorithmParameterSpec, arg3: java.security.SecureRandom, /) -> None: ...

class KeyGenerator(java.lang.Object):
    def __init__(self, keyGenSpi: KeyGeneratorSpi, provider: java.security.Provider, algorithm: str | java.lang.String, /) -> None: ...
    def generateKey(self) -> SecretKey: ...
    def getAlgorithm(self) -> str: ...
    @typing.overload
    @staticmethod
    def getInstance(algorithm: str | java.lang.String, /) -> KeyGenerator: ...
    @typing.overload
    @staticmethod
    def getInstance(algorithm: str | java.lang.String, provider: str | java.lang.String, /) -> KeyGenerator: ...
    @typing.overload
    @staticmethod
    def getInstance(algorithm: str | java.lang.String, provider: java.security.Provider, /) -> KeyGenerator: ...
    def getProvider(self) -> java.security.Provider: ...
    @typing.overload
    def init(self, keysize: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def init(self, random: java.security.SecureRandom, /) -> None: ...
    @typing.overload
    def init(self, params: java.security.spec.AlgorithmParameterSpec, /) -> None: ...
    @typing.overload
    def init(self, keysize: int | java.jint | java.lang.Integer, random: java.security.SecureRandom, /) -> None: ...
    @typing.overload
    def init(self, params: java.security.spec.AlgorithmParameterSpec, random: java.security.SecureRandom, /) -> None: ...

class KeyGeneratorSpi(java.lang.Object):
    def __init__(self) -> None: ...
    def engineGenerateKey(self) -> SecretKey: ...
    @typing.overload
    def engineInit(self, arg1: java.security.SecureRandom, /) -> None: ...
    @typing.overload
    def engineInit(self, arg1: int | java.jint | java.lang.Integer, arg2: java.security.SecureRandom, /) -> None: ...
    @typing.overload
    def engineInit(self, arg1: java.security.spec.AlgorithmParameterSpec, arg2: java.security.SecureRandom, /) -> None: ...

class Mac(java.lang.Cloneable):
    def __init__(self, macSpi: MacSpi, provider: java.security.Provider, algorithm: str | java.lang.String, /) -> None: ...
    def clone(self) -> java.lang.Object: ...
    @typing.overload
    def doFinal(self) -> java.chaquopy.JavaArrayJByte: ...
    @typing.overload
    def doFinal(self, input: java.chaquopy.JavaArrayJByte, /) -> java.chaquopy.JavaArrayJByte: ...
    @typing.overload
    def doFinal(self, output: java.chaquopy.JavaArrayJByte, outOffset: int | java.jint | java.lang.Integer, /) -> None: ...
    def getAlgorithm(self) -> str: ...
    @typing.overload
    @staticmethod
    def getInstance(algorithm: str | java.lang.String, /) -> Mac: ...
    @typing.overload
    @staticmethod
    def getInstance(algorithm: str | java.lang.String, provider: str | java.lang.String, /) -> Mac: ...
    @typing.overload
    @staticmethod
    def getInstance(algorithm: str | java.lang.String, provider: java.security.Provider, /) -> Mac: ...
    def getMacLength(self) -> int: ...
    def getProvider(self) -> java.security.Provider: ...
    @typing.overload
    def init(self, key: java.security.Key, /) -> None: ...
    @typing.overload
    def init(self, key: java.security.Key, params: java.security.spec.AlgorithmParameterSpec, /) -> None: ...
    def reset(self) -> None: ...
    @typing.overload
    def update(self, input: int | java.jbyte | java.lang.Byte, /) -> None: ...
    @typing.overload
    def update(self, input: java.nio.ByteBuffer, /) -> None: ...
    @typing.overload
    def update(self, input: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def update(self, input: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> None: ...

class MacSpi(java.lang.Object):
    def __init__(self) -> None: ...
    def clone(self) -> java.lang.Object: ...
    def engineDoFinal(self) -> java.chaquopy.JavaArrayJByte: ...
    def engineGetMacLength(self) -> int: ...
    def engineInit(self, arg1: java.security.Key, arg2: java.security.spec.AlgorithmParameterSpec, /) -> None: ...
    def engineReset(self) -> None: ...
    @typing.overload
    def engineUpdate(self, arg1: int | java.jbyte | java.lang.Byte, /) -> None: ...
    @typing.overload
    def engineUpdate(self, input: java.nio.ByteBuffer, /) -> None: ...
    @typing.overload
    def engineUpdate(self, arg1: java.chaquopy.JavaArrayJByte, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...

class NoSuchPaddingException(java.security.GeneralSecurityException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, msg: str | java.lang.String, /) -> None: ...

class NullCipher(Cipher):
    def __init__(self) -> None: ...

class SealedObject(java.io.Serializable):
    encodedParams: java.chaquopy.JavaArrayJByte = ...
    @typing.overload
    def __init__(self, so: SealedObject, /) -> None: ...
    @typing.overload
    def __init__(self, object: java.io.Serializable, c: Cipher, /) -> None: ...
    def getAlgorithm(self) -> str: ...
    @typing.overload
    def getObject(self, key: java.security.Key, /) -> java.lang.Object: ...
    @typing.overload
    def getObject(self, c: Cipher, /) -> java.lang.Object: ...
    @typing.overload
    def getObject(self, key: java.security.Key, provider: str | java.lang.String, /) -> java.lang.Object: ...

class SecretKey(java.security.Key, javax.security.auth.Destroyable):
    serialVersionUID: typing.ClassVar[int] = ...

class SecretKeyFactory(java.lang.Object):
    def __init__(self, keyFacSpi: SecretKeyFactorySpi, provider: java.security.Provider, algorithm: str | java.lang.String, /) -> None: ...
    def generateSecret(self, keySpec: java.security.spec.KeySpec, /) -> SecretKey: ...
    def getAlgorithm(self) -> str: ...
    @typing.overload
    @staticmethod
    def getInstance(algorithm: str | java.lang.String, /) -> SecretKeyFactory: ...
    @typing.overload
    @staticmethod
    def getInstance(algorithm: str | java.lang.String, provider: str | java.lang.String, /) -> SecretKeyFactory: ...
    @typing.overload
    @staticmethod
    def getInstance(algorithm: str | java.lang.String, provider: java.security.Provider, /) -> SecretKeyFactory: ...
    def getKeySpec(self, key: SecretKey, keySpec: typing.Type[java.lang.Object], /) -> java.security.spec.KeySpec: ...
    def getProvider(self) -> java.security.Provider: ...
    def translateKey(self, key: SecretKey, /) -> SecretKey: ...

class SecretKeyFactorySpi(java.lang.Object):
    def __init__(self) -> None: ...
    def engineGenerateSecret(self, arg1: java.security.spec.KeySpec, /) -> SecretKey: ...
    def engineGetKeySpec(self, arg1: SecretKey, arg2: typing.Type[java.lang.Object], /) -> java.security.spec.KeySpec: ...
    def engineTranslateKey(self, arg1: SecretKey, /) -> SecretKey: ...

class ShortBufferException(java.security.GeneralSecurityException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, msg: str | java.lang.String, /) -> None: ...



import typing

import java.io
import java.lang
import java.net
import java.nio.channels
import java.nio.file
import java.nio.file.attribute
import java.util
import java.util.concurrent

class FileSystemProvider(java.lang.Object):
    def __init__(self) -> None: ...
    def checkAccess(self, arg1: java.nio.file.Path, /, *arg2: java.nio.file.AccessMode) -> None: ...
    def copy(self, arg1: java.nio.file.Path, arg2: java.nio.file.Path, /, *arg3: java.nio.file.CopyOption) -> None: ...
    def createDirectory(self, arg1: java.nio.file.Path, /, *arg2: java.nio.file.attribute.FileAttribute[java.lang.Object]) -> None: ...
    def createLink(self, link: java.nio.file.Path, existing: java.nio.file.Path, /) -> None: ...
    def createSymbolicLink(self, link: java.nio.file.Path, target: java.nio.file.Path, /, *attrs: java.nio.file.attribute.FileAttribute[java.lang.Object]) -> None: ...
    def delete(self, arg1: java.nio.file.Path, /) -> None: ...
    def deleteIfExists(self, path: java.nio.file.Path, /) -> bool: ...
    _getFileAttributeView__V = typing.TypeVar('_getFileAttributeView__V')  # <V>
    def getFileAttributeView(self, arg1: java.nio.file.Path, arg2: typing.Type[_getFileAttributeView__V], /, *arg3: java.nio.file.LinkOption) -> _getFileAttributeView__V: ...
    def getFileStore(self, arg1: java.nio.file.Path, /) -> java.nio.file.FileStore: ...
    def getFileSystem(self, arg1: java.net.URI, /) -> java.nio.file.FileSystem: ...
    def getPath(self, arg1: java.net.URI, /) -> java.nio.file.Path: ...
    def getScheme(self) -> str: ...
    @staticmethod
    def installedProviders() -> java.util.List[FileSystemProvider]: ...
    def isHidden(self, arg1: java.nio.file.Path, /) -> bool: ...
    def isSameFile(self, arg1: java.nio.file.Path, arg2: java.nio.file.Path, /) -> bool: ...
    def move(self, arg1: java.nio.file.Path, arg2: java.nio.file.Path, /, *arg3: java.nio.file.CopyOption) -> None: ...
    def newAsynchronousFileChannel(self, path: java.nio.file.Path, options: java.util.Set[java.nio.file.OpenOption], executor: java.util.concurrent.ExecutorService, /, *attrs: java.nio.file.attribute.FileAttribute[java.lang.Object]) -> java.nio.channels.AsynchronousFileChannel: ...
    def newByteChannel(self, arg1: java.nio.file.Path, arg2: java.util.Set[java.nio.file.OpenOption], /, *arg3: java.nio.file.attribute.FileAttribute[java.lang.Object]) -> java.nio.channels.SeekableByteChannel: ...
    def newDirectoryStream(self, arg1: java.nio.file.Path, arg2: java.nio.file.DirectoryStream.Filter[java.nio.file.Path], /) -> java.nio.file.DirectoryStream[java.nio.file.Path]: ...
    def newFileChannel(self, path: java.nio.file.Path, options: java.util.Set[java.nio.file.OpenOption], /, *attrs: java.nio.file.attribute.FileAttribute[java.lang.Object]) -> java.nio.channels.FileChannel: ...
    @typing.overload
    def newFileSystem(self, arg1: java.net.URI, arg2: java.util.Map[java.lang.String, java.lang.Object], /) -> java.nio.file.FileSystem: ...
    @typing.overload
    def newFileSystem(self, path: java.nio.file.Path, env: java.util.Map[java.lang.String, java.lang.Object], /) -> java.nio.file.FileSystem: ...
    def newInputStream(self, path: java.nio.file.Path, /, *options: java.nio.file.OpenOption) -> java.io.InputStream: ...
    def newOutputStream(self, path: java.nio.file.Path, /, *options: java.nio.file.OpenOption) -> java.io.OutputStream: ...
    _readAttributes_0__A = typing.TypeVar('_readAttributes_0__A')  # <A>
    @typing.overload
    def readAttributes(self, arg1: java.nio.file.Path, arg2: typing.Type[_readAttributes_0__A], /, *arg3: java.nio.file.LinkOption) -> _readAttributes_0__A: ...
    @typing.overload
    def readAttributes(self, arg1: java.nio.file.Path, arg2: str | java.lang.String, /, *arg3: java.nio.file.LinkOption) -> java.util.Map[java.lang.String, java.lang.Object]: ...
    def readSymbolicLink(self, link: java.nio.file.Path, /) -> java.nio.file.Path: ...
    def setAttribute(self, arg1: java.nio.file.Path, arg2: str | java.lang.String, arg3: java.lang.Object | int | bool | float | str, /, *arg4: java.nio.file.LinkOption) -> None: ...

class FileTypeDetector(java.lang.Object):
    def __init__(self) -> None: ...
    def probeContentType(self, arg1: java.nio.file.Path, /) -> str: ...



import typing

import android.app
import android.content
import android.content.pm
import android.os
import android.view
import java
import java.lang
import java.util
import java.util.concurrent

class AppOwnedSdkSandboxInterface(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AppOwnedSdkSandboxInterface]] = ...
    def __init__(self, name: str | java.lang.String, version: int | java.jlong | java.lang.Long, binder: android.os.IBinder, /) -> None: ...
    def describeContents(self) -> int: ...
    def getInterface(self) -> android.os.IBinder: ...
    def getName(self) -> str: ...
    def getVersion(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class LoadSdkException(android.os.Parcelable, java.lang.Exception):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[LoadSdkException]] = ...
    def __init__(self, cause: java.lang.Throwable, extraInfo: android.os.Bundle, /) -> None: ...
    def describeContents(self) -> int: ...
    def getExtraInformation(self) -> android.os.Bundle: ...
    def getLoadSdkErrorCode(self) -> int: ...
    def writeToParcel(self, destination: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class RequestSurfacePackageException(java.lang.Exception):
    @typing.overload
    def __init__(self, requestSurfacePackageErrorCode: int | java.jint | java.lang.Integer, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, requestSurfacePackageErrorCode: int | java.jint | java.lang.Integer, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...
    @typing.overload
    def __init__(self, requestSurfacePackageErrorCode: int | java.jint | java.lang.Integer, message: str | java.lang.String, cause: java.lang.Throwable, extraInfo: android.os.Bundle, /) -> None: ...
    def getExtraErrorInformation(self) -> android.os.Bundle: ...
    def getRequestSurfacePackageErrorCode(self) -> int: ...

class SandboxedSdk(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SandboxedSdk]] = ...
    def __init__(self, sdkInterface: android.os.IBinder, /) -> None: ...
    def describeContents(self) -> int: ...
    def getInterface(self) -> android.os.IBinder | None: ...
    def getSharedLibraryInfo(self) -> android.content.pm.SharedLibraryInfo: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class SandboxedSdkProvider(java.lang.Object):
    def __init__(self) -> None: ...
    def attachContext(self, context: android.content.Context, /) -> None: ...
    def beforeUnloadSdk(self) -> None: ...
    def getContext(self) -> android.content.Context | None: ...
    def getView(self, arg1: android.content.Context, arg2: android.os.Bundle, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> android.view.View: ...
    def onLoadSdk(self, arg1: android.os.Bundle, /) -> SandboxedSdk: ...

class SdkSandboxManager(java.lang.Object):
    EXTRA_DISPLAY_ID: typing.ClassVar[str] = ...
    EXTRA_HEIGHT_IN_PIXELS: typing.ClassVar[str] = ...
    EXTRA_HOST_TOKEN: typing.ClassVar[str] = ...
    EXTRA_SURFACE_PACKAGE: typing.ClassVar[str] = ...
    EXTRA_WIDTH_IN_PIXELS: typing.ClassVar[str] = ...
    LOAD_SDK_ALREADY_LOADED: typing.ClassVar[int] = ...
    LOAD_SDK_INTERNAL_ERROR: typing.ClassVar[int] = ...
    LOAD_SDK_NOT_FOUND: typing.ClassVar[int] = ...
    LOAD_SDK_SDK_DEFINED_ERROR: typing.ClassVar[int] = ...
    LOAD_SDK_SDK_SANDBOX_DISABLED: typing.ClassVar[int] = ...
    REQUEST_SURFACE_PACKAGE_INTERNAL_ERROR: typing.ClassVar[int] = ...
    REQUEST_SURFACE_PACKAGE_SDK_NOT_LOADED: typing.ClassVar[int] = ...
    SDK_SANDBOX_PROCESS_NOT_AVAILABLE: typing.ClassVar[int] = ...
    SDK_SANDBOX_SERVICE: typing.ClassVar[str] = ...
    SDK_SANDBOX_STATE_DISABLED: typing.ClassVar[int] = ...
    SDK_SANDBOX_STATE_ENABLED_PROCESS_ISOLATION: typing.ClassVar[int] = ...
    def addSdkSandboxProcessDeathCallback(self, callbackExecutor: java.util.concurrent.Executor, callback: SdkSandboxManager.SdkSandboxProcessDeathCallback, /) -> None: ...
    def addSyncedSharedPreferencesKeys(self, keys: java.util.Set[java.lang.String], /) -> None: ...
    def getAppOwnedSdkSandboxInterfaces(self) -> java.util.List[AppOwnedSdkSandboxInterface]: ...
    def getSandboxedSdks(self) -> java.util.List[SandboxedSdk]: ...
    @staticmethod
    def getSdkSandboxState() -> int: ...
    def getSyncedSharedPreferencesKeys(self) -> java.util.Set[java.lang.String]: ...
    def loadSdk(self, sdkName: str | java.lang.String, params: android.os.Bundle, executor: java.util.concurrent.Executor, receiver: android.os.OutcomeReceiver[SandboxedSdk, LoadSdkException], /) -> None: ...
    def registerAppOwnedSdkSandboxInterface(self, appOwnedSdkSandboxInterface: AppOwnedSdkSandboxInterface, /) -> None: ...
    def removeSdkSandboxProcessDeathCallback(self, callback: SdkSandboxManager.SdkSandboxProcessDeathCallback, /) -> None: ...
    def removeSyncedSharedPreferencesKeys(self, keys: java.util.Set[java.lang.String], /) -> None: ...
    def requestSurfacePackage(self, sdkName: str | java.lang.String, params: android.os.Bundle, callbackExecutor: java.util.concurrent.Executor, receiver: android.os.OutcomeReceiver[android.os.Bundle, RequestSurfacePackageException], /) -> None: ...
    def startSdkSandboxActivity(self, fromActivity: android.app.Activity, sdkActivityToken: android.os.IBinder, /) -> None: ...
    def unloadSdk(self, sdkName: str | java.lang.String, /) -> None: ...
    def unregisterAppOwnedSdkSandboxInterface(self, name: str | java.lang.String, /) -> None: ...

    class SdkSandboxProcessDeathCallback(java.lang.Object):
        def onSdkSandboxDied(self) -> None: ...



import android.content
import java.chaquopy
import java.lang

class CleartextNetworkViolation(Violation): ...

class ContentUriWithoutPermissionViolation(Violation): ...

class CredentialProtectedWhileLockedViolation(Violation): ...

class CustomViolation(Violation): ...

class DiskReadViolation(Violation): ...

class DiskWriteViolation(Violation): ...

class ExplicitGcViolation(Violation): ...

class FileUriExposedViolation(Violation): ...

class ImplicitDirectBootViolation(Violation): ...

class IncorrectContextUseViolation(Violation):
    def __init__(self, message: str | java.lang.String, originStack: java.lang.Throwable, /) -> None: ...

class InstanceCountViolation(Violation):
    def getNumberOfInstances(self) -> int: ...

class IntentReceiverLeakedViolation(Violation): ...

class LeakedClosableViolation(Violation): ...

class NetworkViolation(Violation): ...

class NonSdkApiUsedViolation(Violation): ...

class ResourceMismatchViolation(Violation): ...

class ServiceConnectionLeakedViolation(Violation): ...

class SqliteObjectLeakedViolation(Violation): ...

class UnbufferedIoViolation(Violation): ...

class UnsafeIntentLaunchViolation(Violation):
    def __init__(self, intent: android.content.Intent, /) -> None: ...
    def getIntent(self) -> android.content.Intent | None: ...

class UntaggedSocketViolation(Violation): ...

class Violation(java.lang.Throwable):
    def fillInStackTrace(self) -> java.lang.Throwable: ...
    def hashCode(self) -> int: ...
    def initCause(self, cause: java.lang.Throwable, /) -> java.lang.Throwable: ...
    def setStackTrace(self, stackTrace: java.chaquopy.JavaArray[java.lang.StackTraceElement], /) -> None: ...

class WebViewMethodCalledOnWrongThreadViolation(Violation): ...



import typing

import java.lang
import org.xml.sax

class Element(java.lang.Object):
    @typing.overload
    def getChild(self, localName: str | java.lang.String, /) -> Element: ...
    @typing.overload
    def getChild(self, uri: str | java.lang.String, localName: str | java.lang.String, /) -> Element: ...
    @typing.overload
    def requireChild(self, localName: str | java.lang.String, /) -> Element: ...
    @typing.overload
    def requireChild(self, uri: str | java.lang.String, localName: str | java.lang.String, /) -> Element: ...
    def setElementListener(self, elementListener: ElementListener, /) -> None: ...
    def setEndElementListener(self, endElementListener: EndElementListener, /) -> None: ...
    def setEndTextElementListener(self, endTextElementListener: EndTextElementListener, /) -> None: ...
    def setStartElementListener(self, startElementListener: StartElementListener, /) -> None: ...
    def setTextElementListener(self, elementListener: TextElementListener, /) -> None: ...
    def toString(self) -> str: ...

class ElementListener(EndElementListener, StartElementListener): ...

class EndElementListener(java.lang.Object):
    def end(self) -> None: ...

class EndTextElementListener(java.lang.Object):
    def end(self, arg1: str | java.lang.String, /) -> None: ...

class RootElement(Element):
    @typing.overload
    def __init__(self, localName: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, uri: str | java.lang.String, localName: str | java.lang.String, /) -> None: ...
    def getContentHandler(self) -> org.xml.sax.ContentHandler: ...

class StartElementListener(java.lang.Object):
    def start(self, arg1: org.xml.sax.Attributes, /) -> None: ...

class TextElementListener(EndTextElementListener, StartElementListener): ...
